TRUST_E_PROVIDER_UNKNOWN: int
TRUST_E_ACTION_UNKNOWN: int
TRUST_E_SUBJECT_FORM_UNKNOWN: int
TRUST_E_SUBJECT_NOT_TRUSTED: int
FACILITY_WINRM: int
FACILITY_WINDOWSUPDATE: int
FACILITY_WINDOWS_DEFENDER: int
FACILITY_WINDOWS_CE: int
FACILITY_WINDOWS: int
FACILITY_URT: int
FACILITY_UMI: int
FACILITY_TPM_SOFTWARE: int
FACILITY_TPM_SERVICES: int
FACILITY_SXS: int
FACILITY_STORAGE: int
FACILITY_STATE_MANAGEMENT: int
FACILITY_SSPI: int
FACILITY_SCARD: int
FACILITY_SHELL: int
FACILITY_SETUPAPI: int
FACILITY_SECURITY: int
FACILITY_RPC: int
FACILITY_PLA: int
FACILITY_WIN32: int
FACILITY_CONTROL: int
FACILITY_NULL: int
FACILITY_NDIS: int
FACILITY_METADIRECTORY: int
FACILITY_MSMQ: int
FACILITY_MEDIASERVER: int
FACILITY_INTERNET: int
FACILITY_ITF: int
FACILITY_USERMODE_HYPERVISOR: int
FACILITY_HTTP: int
FACILITY_GRAPHICS: int
FACILITY_FWP: int
FACILITY_FVE: int
FACILITY_USERMODE_FILTER_MANAGER: int
FACILITY_DPLAY: int
FACILITY_DISPATCH: int
FACILITY_DIRECTORYSERVICE: int
FACILITY_CONFIGURATION: int
FACILITY_COMPLUS: int
FACILITY_USERMODE_COMMONLOG: int
FACILITY_CMI: int
FACILITY_CERT: int
FACILITY_BACKGROUNDCOPY: int
FACILITY_ACS: int
FACILITY_AAF: int
ERROR_SUCCESS: int
NO_ERROR: int
S_OK: int
S_FALSE: int
ERROR_INVALID_FUNCTION: int
ERROR_FILE_NOT_FOUND: int
ERROR_PATH_NOT_FOUND: int
ERROR_TOO_MANY_OPEN_FILES: int
ERROR_ACCESS_DENIED: int
ERROR_INVALID_HANDLE: int
ERROR_ARENA_TRASHED: int
ERROR_NOT_ENOUGH_MEMORY: int
ERROR_INVALID_BLOCK: int
ERROR_BAD_ENVIRONMENT: int
ERROR_BAD_FORMAT: int
ERROR_INVALID_ACCESS: int
ERROR_INVALID_DATA: int
ERROR_OUTOFMEMORY: int
ERROR_INVALID_DRIVE: int
ERROR_CURRENT_DIRECTORY: int
ERROR_NOT_SAME_DEVICE: int
ERROR_NO_MORE_FILES: int
ERROR_WRITE_PROTECT: int
ERROR_BAD_UNIT: int
ERROR_NOT_READY: int
ERROR_BAD_COMMAND: int
ERROR_CRC: int
ERROR_BAD_LENGTH: int
ERROR_SEEK: int
ERROR_NOT_DOS_DISK: int
ERROR_SECTOR_NOT_FOUND: int
ERROR_OUT_OF_PAPER: int
ERROR_WRITE_FAULT: int
ERROR_READ_FAULT: int
ERROR_GEN_FAILURE: int
ERROR_SHARING_VIOLATION: int
ERROR_LOCK_VIOLATION: int
ERROR_WRONG_DISK: int
ERROR_SHARING_BUFFER_EXCEEDED: int
ERROR_HANDLE_EOF: int
ERROR_HANDLE_DISK_FULL: int
ERROR_NOT_SUPPORTED: int
ERROR_REM_NOT_LIST: int
ERROR_DUP_NAME: int
ERROR_BAD_NETPATH: int
ERROR_NETWORK_BUSY: int
ERROR_DEV_NOT_EXIST: int
ERROR_TOO_MANY_CMDS: int
ERROR_ADAP_HDW_ERR: int
ERROR_BAD_NET_RESP: int
ERROR_UNEXP_NET_ERR: int
ERROR_BAD_REM_ADAP: int
ERROR_PRINTQ_FULL: int
ERROR_NO_SPOOL_SPACE: int
ERROR_PRINT_CANCELLED: int
ERROR_NETNAME_DELETED: int
ERROR_NETWORK_ACCESS_DENIED: int
ERROR_BAD_DEV_TYPE: int
ERROR_BAD_NET_NAME: int
ERROR_TOO_MANY_NAMES: int
ERROR_TOO_MANY_SESS: int
ERROR_SHARING_PAUSED: int
ERROR_REQ_NOT_ACCEP: int
ERROR_REDIR_PAUSED: int
ERROR_FILE_EXISTS: int
ERROR_CANNOT_MAKE: int
ERROR_FAIL_I24: int
ERROR_OUT_OF_STRUCTURES: int
ERROR_ALREADY_ASSIGNED: int
ERROR_INVALID_PASSWORD: int
ERROR_INVALID_PARAMETER: int
ERROR_NET_WRITE_FAULT: int
ERROR_NO_PROC_SLOTS: int
ERROR_TOO_MANY_SEMAPHORES: int
ERROR_EXCL_SEM_ALREADY_OWNED: int
ERROR_SEM_IS_SET: int
ERROR_TOO_MANY_SEM_REQUESTS: int
ERROR_INVALID_AT_INTERRUPT_TIME: int
ERROR_SEM_OWNER_DIED: int
ERROR_SEM_USER_LIMIT: int
ERROR_DISK_CHANGE: int
ERROR_DRIVE_LOCKED: int
ERROR_BROKEN_PIPE: int
ERROR_OPEN_FAILED: int
ERROR_BUFFER_OVERFLOW: int
ERROR_DISK_FULL: int
ERROR_NO_MORE_SEARCH_HANDLES: int
ERROR_INVALID_TARGET_HANDLE: int
ERROR_INVALID_CATEGORY: int
ERROR_INVALID_VERIFY_SWITCH: int
ERROR_BAD_DRIVER_LEVEL: int
ERROR_CALL_NOT_IMPLEMENTED: int
ERROR_SEM_TIMEOUT: int
ERROR_INSUFFICIENT_BUFFER: int
ERROR_INVALID_NAME: int
ERROR_INVALID_LEVEL: int
ERROR_NO_VOLUME_LABEL: int
ERROR_MOD_NOT_FOUND: int
ERROR_PROC_NOT_FOUND: int
ERROR_WAIT_NO_CHILDREN: int
ERROR_CHILD_NOT_COMPLETE: int
ERROR_DIRECT_ACCESS_HANDLE: int
ERROR_NEGATIVE_SEEK: int
ERROR_SEEK_ON_DEVICE: int
ERROR_IS_JOIN_TARGET: int
ERROR_IS_JOINED: int
ERROR_IS_SUBSTED: int
ERROR_NOT_JOINED: int
ERROR_NOT_SUBSTED: int
ERROR_JOIN_TO_JOIN: int
ERROR_SUBST_TO_SUBST: int
ERROR_JOIN_TO_SUBST: int
ERROR_SUBST_TO_JOIN: int
ERROR_BUSY_DRIVE: int
ERROR_SAME_DRIVE: int
ERROR_DIR_NOT_ROOT: int
ERROR_DIR_NOT_EMPTY: int
ERROR_IS_SUBST_PATH: int
ERROR_IS_JOIN_PATH: int
ERROR_PATH_BUSY: int
ERROR_IS_SUBST_TARGET: int
ERROR_SYSTEM_TRACE: int
ERROR_INVALID_EVENT_COUNT: int
ERROR_TOO_MANY_MUXWAITERS: int
ERROR_INVALID_LIST_FORMAT: int
ERROR_LABEL_TOO_LONG: int
ERROR_TOO_MANY_TCBS: int
ERROR_SIGNAL_REFUSED: int
ERROR_DISCARDED: int
ERROR_NOT_LOCKED: int
ERROR_BAD_THREADID_ADDR: int
ERROR_BAD_ARGUMENTS: int
ERROR_BAD_PATHNAME: int
ERROR_SIGNAL_PENDING: int
ERROR_MAX_THRDS_REACHED: int
ERROR_LOCK_FAILED: int
ERROR_BUSY: int
ERROR_CANCEL_VIOLATION: int
ERROR_ATOMIC_LOCKS_NOT_SUPPORTED: int
ERROR_INVALID_SEGMENT_NUMBER: int
ERROR_INVALID_ORDINAL: int
ERROR_ALREADY_EXISTS: int
ERROR_INVALID_FLAG_NUMBER: int
ERROR_SEM_NOT_FOUND: int
ERROR_INVALID_STARTING_CODESEG: int
ERROR_INVALID_STACKSEG: int
ERROR_INVALID_MODULETYPE: int
ERROR_INVALID_EXE_SIGNATURE: int
ERROR_EXE_MARKED_INVALID: int
ERROR_BAD_EXE_FORMAT: int
ERROR_ITERATED_DATA_EXCEEDS_64k: int
ERROR_INVALID_MINALLOCSIZE: int
ERROR_DYNLINK_FROM_INVALID_RING: int
ERROR_IOPL_NOT_ENABLED: int
ERROR_INVALID_SEGDPL: int
ERROR_AUTODATASEG_EXCEEDS_64k: int
ERROR_RING2SEG_MUST_BE_MOVABLE: int
ERROR_RELOC_CHAIN_XEEDS_SEGLIM: int
ERROR_INFLOOP_IN_RELOC_CHAIN: int
ERROR_ENVVAR_NOT_FOUND: int
ERROR_NO_SIGNAL_SENT: int
ERROR_FILENAME_EXCED_RANGE: int
ERROR_RING2_STACK_IN_USE: int
ERROR_META_EXPANSION_TOO_LONG: int
ERROR_INVALID_SIGNAL_NUMBER: int
ERROR_THREAD_1_INACTIVE: int
ERROR_LOCKED: int
ERROR_TOO_MANY_MODULES: int
ERROR_NESTING_NOT_ALLOWED: int
ERROR_EXE_MACHINE_TYPE_MISMATCH: int
ERROR_EXE_CANNOT_MODIFY_SIGNED_BINARY: int
ERROR_EXE_CANNOT_MODIFY_STRONG_SIGNED_BINARY: int
ERROR_FILE_CHECKED_OUT: int
ERROR_CHECKOUT_REQUIRED: int
ERROR_BAD_FILE_TYPE: int
ERROR_FILE_TOO_LARGE: int
ERROR_FORMS_AUTH_REQUIRED: int
ERROR_VIRUS_INFECTED: int
ERROR_VIRUS_DELETED: int
ERROR_PIPE_LOCAL: int
ERROR_BAD_PIPE: int
ERROR_PIPE_BUSY: int
ERROR_NO_DATA: int
ERROR_PIPE_NOT_CONNECTED: int
ERROR_MORE_DATA: int
ERROR_VC_DISCONNECTED: int
ERROR_INVALID_EA_NAME: int
ERROR_EA_LIST_INCONSISTENT: int
WAIT_TIMEOUT: int
ERROR_NO_MORE_ITEMS: int
ERROR_CANNOT_COPY: int
ERROR_DIRECTORY: int
ERROR_EAS_DIDNT_FIT: int
ERROR_EA_FILE_CORRUPT: int
ERROR_EA_TABLE_FULL: int
ERROR_INVALID_EA_HANDLE: int
ERROR_EAS_NOT_SUPPORTED: int
ERROR_NOT_OWNER: int
ERROR_TOO_MANY_POSTS: int
ERROR_PARTIAL_COPY: int
ERROR_OPLOCK_NOT_GRANTED: int
ERROR_INVALID_OPLOCK_PROTOCOL: int
ERROR_DISK_TOO_FRAGMENTED: int
ERROR_DELETE_PENDING: int
ERROR_MR_MID_NOT_FOUND: int
ERROR_SCOPE_NOT_FOUND: int
ERROR_FAIL_NOACTION_REBOOT: int
ERROR_FAIL_SHUTDOWN: int
ERROR_FAIL_RESTART: int
ERROR_MAX_SESSIONS_REACHED: int
ERROR_THREAD_MODE_ALREADY_BACKGROUND: int
ERROR_THREAD_MODE_NOT_BACKGROUND: int
ERROR_PROCESS_MODE_ALREADY_BACKGROUND: int
ERROR_PROCESS_MODE_NOT_BACKGROUND: int
ERROR_INVALID_ADDRESS: int
ERROR_USER_PROFILE_LOAD: int
ERROR_ARITHMETIC_OVERFLOW: int
ERROR_PIPE_CONNECTED: int
ERROR_PIPE_LISTENING: int
ERROR_VERIFIER_STOP: int
ERROR_ABIOS_ERROR: int
ERROR_WX86_WARNING: int
ERROR_WX86_ERROR: int
ERROR_TIMER_NOT_CANCELED: int
ERROR_UNWIND: int
ERROR_BAD_STACK: int
ERROR_INVALID_UNWIND_TARGET: int
ERROR_INVALID_PORT_ATTRIBUTES: int
ERROR_PORT_MESSAGE_TOO_LONG: int
ERROR_INVALID_QUOTA_LOWER: int
ERROR_DEVICE_ALREADY_ATTACHED: int
ERROR_INSTRUCTION_MISALIGNMENT: int
ERROR_PROFILING_NOT_STARTED: int
ERROR_PROFILING_NOT_STOPPED: int
ERROR_COULD_NOT_INTERPRET: int
ERROR_PROFILING_AT_LIMIT: int
ERROR_CANT_WAIT: int
ERROR_CANT_TERMINATE_SELF: int
ERROR_UNEXPECTED_MM_CREATE_ERR: int
ERROR_UNEXPECTED_MM_MAP_ERROR: int
ERROR_UNEXPECTED_MM_EXTEND_ERR: int
ERROR_BAD_FUNCTION_TABLE: int
ERROR_NO_GUID_TRANSLATION: int
ERROR_INVALID_LDT_SIZE: int
ERROR_INVALID_LDT_OFFSET: int
ERROR_INVALID_LDT_DESCRIPTOR: int
ERROR_TOO_MANY_THREADS: int
ERROR_THREAD_NOT_IN_PROCESS: int
ERROR_PAGEFILE_QUOTA_EXCEEDED: int
ERROR_LOGON_SERVER_CONFLICT: int
ERROR_SYNCHRONIZATION_REQUIRED: int
ERROR_NET_OPEN_FAILED: int
ERROR_IO_PRIVILEGE_FAILED: int
ERROR_CONTROL_C_EXIT: int
ERROR_MISSING_SYSTEMFILE: int
ERROR_UNHANDLED_EXCEPTION: int
ERROR_APP_INIT_FAILURE: int
ERROR_PAGEFILE_CREATE_FAILED: int
ERROR_INVALID_IMAGE_HASH: int
ERROR_NO_PAGEFILE: int
ERROR_ILLEGAL_FLOAT_CONTEXT: int
ERROR_NO_EVENT_PAIR: int
ERROR_DOMAIN_CTRLR_CONFIG_ERROR: int
ERROR_ILLEGAL_CHARACTER: int
ERROR_UNDEFINED_CHARACTER: int
ERROR_FLOPPY_VOLUME: int
ERROR_BIOS_FAILED_TO_CONNECT_INTERRUPT: int
ERROR_BACKUP_CONTROLLER: int
ERROR_MUTANT_LIMIT_EXCEEDED: int
ERROR_FS_DRIVER_REQUIRED: int
ERROR_CANNOT_LOAD_REGISTRY_FILE: int
ERROR_DEBUG_ATTACH_FAILED: int
ERROR_SYSTEM_PROCESS_TERMINATED: int
ERROR_DATA_NOT_ACCEPTED: int
ERROR_VDM_HARD_ERROR: int
ERROR_DRIVER_CANCEL_TIMEOUT: int
ERROR_REPLY_MESSAGE_MISMATCH: int
ERROR_LOST_WRITEBEHIND_DATA: int
ERROR_CLIENT_SERVER_PARAMETERS_INVALID: int
ERROR_NOT_TINY_STREAM: int
ERROR_STACK_OVERFLOW_READ: int
ERROR_CONVERT_TO_LARGE: int
ERROR_FOUND_OUT_OF_SCOPE: int
ERROR_ALLOCATE_BUCKET: int
ERROR_MARSHALL_OVERFLOW: int
ERROR_INVALID_VARIANT: int
ERROR_BAD_COMPRESSION_BUFFER: int
ERROR_AUDIT_FAILED: int
ERROR_TIMER_RESOLUTION_NOT_SET: int
ERROR_INSUFFICIENT_LOGON_INFO: int
ERROR_BAD_DLL_ENTRYPOINT: int
ERROR_BAD_SERVICE_ENTRYPOINT: int
ERROR_IP_ADDRESS_CONFLICT1: int
ERROR_IP_ADDRESS_CONFLICT2: int
ERROR_REGISTRY_QUOTA_LIMIT: int
ERROR_NO_CALLBACK_ACTIVE: int
ERROR_PWD_TOO_SHORT: int
ERROR_PWD_TOO_RECENT: int
ERROR_PWD_HISTORY_CONFLICT: int
ERROR_UNSUPPORTED_COMPRESSION: int
ERROR_INVALID_HW_PROFILE: int
ERROR_INVALID_PLUGPLAY_DEVICE_PATH: int
ERROR_QUOTA_LIST_INCONSISTENT: int
ERROR_EVALUATION_EXPIRATION: int
ERROR_ILLEGAL_DLL_RELOCATION: int
ERROR_DLL_INIT_FAILED_LOGOFF: int
ERROR_VALIDATE_CONTINUE: int
ERROR_NO_MORE_MATCHES: int
ERROR_RANGE_LIST_CONFLICT: int
ERROR_SERVER_SID_MISMATCH: int
ERROR_CANT_ENABLE_DENY_ONLY: int
ERROR_FLOAT_MULTIPLE_FAULTS: int
ERROR_FLOAT_MULTIPLE_TRAPS: int
ERROR_NOINTERFACE: int
ERROR_DRIVER_FAILED_SLEEP: int
ERROR_CORRUPT_SYSTEM_FILE: int
ERROR_COMMITMENT_MINIMUM: int
ERROR_PNP_RESTART_ENUMERATION: int
ERROR_SYSTEM_IMAGE_BAD_SIGNATURE: int
ERROR_PNP_REBOOT_REQUIRED: int
ERROR_INSUFFICIENT_POWER: int
ERROR_MULTIPLE_FAULT_VIOLATION: int
ERROR_SYSTEM_SHUTDOWN: int
ERROR_PORT_NOT_SET: int
ERROR_DS_VERSION_CHECK_FAILURE: int
ERROR_RANGE_NOT_FOUND: int
ERROR_NOT_SAFE_MODE_DRIVER: int
ERROR_FAILED_DRIVER_ENTRY: int
ERROR_DEVICE_ENUMERATION_ERROR: int
ERROR_MOUNT_POINT_NOT_RESOLVED: int
ERROR_INVALID_DEVICE_OBJECT_PARAMETER: int
ERROR_MCA_OCCURED: int
ERROR_DRIVER_DATABASE_ERROR: int
ERROR_SYSTEM_HIVE_TOO_LARGE: int
ERROR_DRIVER_FAILED_PRIOR_UNLOAD: int
ERROR_VOLSNAP_PREPARE_HIBERNATE: int
ERROR_HIBERNATION_FAILURE: int
ERROR_FILE_SYSTEM_LIMITATION: int
ERROR_ASSERTION_FAILURE: int
ERROR_ACPI_ERROR: int
ERROR_WOW_ASSERTION: int
ERROR_PNP_BAD_MPS_TABLE: int
ERROR_PNP_TRANSLATION_FAILED: int
ERROR_PNP_IRQ_TRANSLATION_FAILED: int
ERROR_PNP_INVALID_ID: int
ERROR_WAKE_SYSTEM_DEBUGGER: int
ERROR_HANDLES_CLOSED: int
ERROR_EXTRANEOUS_INFORMATION: int
ERROR_RXACT_COMMIT_NECESSARY: int
ERROR_MEDIA_CHECK: int
ERROR_GUID_SUBSTITUTION_MADE: int
ERROR_STOPPED_ON_SYMLINK: int
ERROR_LONGJUMP: int
ERROR_PLUGPLAY_QUERY_VETOED: int
ERROR_UNWIND_CONSOLIDATE: int
ERROR_REGISTRY_HIVE_RECOVERED: int
ERROR_DLL_MIGHT_BE_INSECURE: int
ERROR_DLL_MIGHT_BE_INCOMPATIBLE: int
ERROR_DBG_EXCEPTION_NOT_HANDLED: int
ERROR_DBG_REPLY_LATER: int
ERROR_DBG_UNABLE_TO_PROVIDE_HANDLE: int
ERROR_DBG_TERMINATE_THREAD: int
ERROR_DBG_TERMINATE_PROCESS: int
ERROR_DBG_CONTROL_C: int
ERROR_DBG_PRINTEXCEPTION_C: int
ERROR_DBG_RIPEXCEPTION: int
ERROR_DBG_CONTROL_BREAK: int
ERROR_DBG_COMMAND_EXCEPTION: int
ERROR_OBJECT_NAME_EXISTS: int
ERROR_THREAD_WAS_SUSPENDED: int
ERROR_IMAGE_NOT_AT_BASE: int
ERROR_RXACT_STATE_CREATED: int
ERROR_SEGMENT_NOTIFICATION: int
ERROR_BAD_CURRENT_DIRECTORY: int
ERROR_FT_READ_RECOVERY_FROM_BACKUP: int
ERROR_FT_WRITE_RECOVERY: int
ERROR_IMAGE_MACHINE_TYPE_MISMATCH: int
ERROR_RECEIVE_PARTIAL: int
ERROR_RECEIVE_EXPEDITED: int
ERROR_RECEIVE_PARTIAL_EXPEDITED: int
ERROR_EVENT_DONE: int
ERROR_EVENT_PENDING: int
ERROR_CHECKING_FILE_SYSTEM: int
ERROR_FATAL_APP_EXIT: int
ERROR_PREDEFINED_HANDLE: int
ERROR_WAS_UNLOCKED: int
ERROR_SERVICE_NOTIFICATION: int
ERROR_WAS_LOCKED: int
ERROR_LOG_HARD_ERROR: int
ERROR_ALREADY_WIN32: int
ERROR_IMAGE_MACHINE_TYPE_MISMATCH_EXE: int
ERROR_NO_YIELD_PERFORMED: int
ERROR_TIMER_RESUME_IGNORED: int
ERROR_ARBITRATION_UNHANDLED: int
ERROR_CARDBUS_NOT_SUPPORTED: int
ERROR_MP_PROCESSOR_MISMATCH: int
ERROR_HIBERNATED: int
ERROR_RESUME_HIBERNATION: int
ERROR_FIRMWARE_UPDATED: int
ERROR_DRIVERS_LEAKING_LOCKED_PAGES: int
ERROR_WAKE_SYSTEM: int
ERROR_WAIT_1: int
ERROR_WAIT_2: int
ERROR_WAIT_3: int
ERROR_WAIT_63: int
ERROR_ABANDONED_WAIT_0: int
ERROR_ABANDONED_WAIT_63: int
ERROR_USER_APC: int
ERROR_KERNEL_APC: int
ERROR_ALERTED: int
ERROR_ELEVATION_REQUIRED: int
ERROR_REPARSE: int
ERROR_OPLOCK_BREAK_IN_PROGRESS: int
ERROR_VOLUME_MOUNTED: int
ERROR_RXACT_COMMITTED: int
ERROR_NOTIFY_CLEANUP: int
ERROR_PRIMARY_TRANSPORT_CONNECT_FAILED: int
ERROR_PAGE_FAULT_TRANSITION: int
ERROR_PAGE_FAULT_DEMAND_ZERO: int
ERROR_PAGE_FAULT_COPY_ON_WRITE: int
ERROR_PAGE_FAULT_GUARD_PAGE: int
ERROR_PAGE_FAULT_PAGING_FILE: int
ERROR_CACHE_PAGE_LOCKED: int
ERROR_CRASH_DUMP: int
ERROR_BUFFER_ALL_ZEROS: int
ERROR_REPARSE_OBJECT: int
ERROR_RESOURCE_REQUIREMENTS_CHANGED: int
ERROR_TRANSLATION_COMPLETE: int
ERROR_NOTHING_TO_TERMINATE: int
ERROR_PROCESS_NOT_IN_JOB: int
ERROR_PROCESS_IN_JOB: int
ERROR_VOLSNAP_HIBERNATE_READY: int
ERROR_FSFILTER_OP_COMPLETED_SUCCESSFULLY: int
ERROR_INTERRUPT_VECTOR_ALREADY_CONNECTED: int
ERROR_INTERRUPT_STILL_CONNECTED: int
ERROR_WAIT_FOR_OPLOCK: int
ERROR_DBG_EXCEPTION_HANDLED: int
ERROR_DBG_CONTINUE: int
ERROR_CALLBACK_POP_STACK: int
ERROR_COMPRESSION_DISABLED: int
ERROR_CANTFETCHBACKWARDS: int
ERROR_CANTSCROLLBACKWARDS: int
ERROR_ROWSNOTRELEASED: int
ERROR_BAD_ACCESSOR_FLAGS: int
ERROR_ERRORS_ENCOUNTERED: int
ERROR_NOT_CAPABLE: int
ERROR_REQUEST_OUT_OF_SEQUENCE: int
ERROR_VERSION_PARSE_ERROR: int
ERROR_BADSTARTPOSITION: int
ERROR_MEMORY_HARDWARE: int
ERROR_DISK_REPAIR_DISABLED: int
ERROR_INSUFFICIENT_RESOURCE_FOR_SPECIFIED_SHARED_SECTION_SIZE: int
ERROR_SYSTEM_POWERSTATE_TRANSITION: int
ERROR_SYSTEM_POWERSTATE_COMPLEX_TRANSITION: int
ERROR_MCA_EXCEPTION: int
ERROR_ACCESS_AUDIT_BY_POLICY: int
ERROR_ACCESS_DISABLED_NO_SAFER_UI_BY_POLICY: int
ERROR_ABANDON_HIBERFILE: int
ERROR_LOST_WRITEBEHIND_DATA_NETWORK_DISCONNECTED: int
ERROR_LOST_WRITEBEHIND_DATA_NETWORK_SERVER_ERROR: int
ERROR_LOST_WRITEBEHIND_DATA_LOCAL_DISK_ERROR: int
ERROR_BAD_MCFG_TABLE: int
ERROR_EA_ACCESS_DENIED: int
ERROR_OPERATION_ABORTED: int
ERROR_IO_INCOMPLETE: int
ERROR_IO_PENDING: int
ERROR_NOACCESS: int
ERROR_SWAPERROR: int
ERROR_STACK_OVERFLOW: int
ERROR_INVALID_MESSAGE: int
ERROR_CAN_NOT_COMPLETE: int
ERROR_INVALID_FLAGS: int
ERROR_UNRECOGNIZED_VOLUME: int
ERROR_FILE_INVALID: int
ERROR_FULLSCREEN_MODE: int
ERROR_NO_TOKEN: int
ERROR_BADDB: int
ERROR_BADKEY: int
ERROR_CANTOPEN: int
ERROR_CANTREAD: int
ERROR_CANTWRITE: int
ERROR_REGISTRY_RECOVERED: int
ERROR_REGISTRY_CORRUPT: int
ERROR_REGISTRY_IO_FAILED: int
ERROR_NOT_REGISTRY_FILE: int
ERROR_KEY_DELETED: int
ERROR_NO_LOG_SPACE: int
ERROR_KEY_HAS_CHILDREN: int
ERROR_CHILD_MUST_BE_VOLATILE: int
ERROR_NOTIFY_ENUM_DIR: int
ERROR_DEPENDENT_SERVICES_RUNNING: int
ERROR_INVALID_SERVICE_CONTROL: int
ERROR_SERVICE_REQUEST_TIMEOUT: int
ERROR_SERVICE_NO_THREAD: int
ERROR_SERVICE_DATABASE_LOCKED: int
ERROR_SERVICE_ALREADY_RUNNING: int
ERROR_INVALID_SERVICE_ACCOUNT: int
ERROR_SERVICE_DISABLED: int
ERROR_CIRCULAR_DEPENDENCY: int
ERROR_SERVICE_DOES_NOT_EXIST: int
ERROR_SERVICE_CANNOT_ACCEPT_CTRL: int
ERROR_SERVICE_NOT_ACTIVE: int
ERROR_FAILED_SERVICE_CONTROLLER_CONNECT: int
ERROR_EXCEPTION_IN_SERVICE: int
ERROR_DATABASE_DOES_NOT_EXIST: int
ERROR_SERVICE_SPECIFIC_ERROR: int
ERROR_PROCESS_ABORTED: int
ERROR_SERVICE_DEPENDENCY_FAIL: int
ERROR_SERVICE_LOGON_FAILED: int
ERROR_SERVICE_START_HANG: int
ERROR_INVALID_SERVICE_LOCK: int
ERROR_SERVICE_MARKED_FOR_DELETE: int
ERROR_SERVICE_EXISTS: int
ERROR_ALREADY_RUNNING_LKG: int
ERROR_SERVICE_DEPENDENCY_DELETED: int
ERROR_BOOT_ALREADY_ACCEPTED: int
ERROR_SERVICE_NEVER_STARTED: int
ERROR_DUPLICATE_SERVICE_NAME: int
ERROR_DIFFERENT_SERVICE_ACCOUNT: int
ERROR_CANNOT_DETECT_DRIVER_FAILURE: int
ERROR_CANNOT_DETECT_PROCESS_ABORT: int
ERROR_NO_RECOVERY_PROGRAM: int
ERROR_SERVICE_NOT_IN_EXE: int
ERROR_NOT_SAFEBOOT_SERVICE: int
ERROR_END_OF_MEDIA: int
ERROR_FILEMARK_DETECTED: int
ERROR_BEGINNING_OF_MEDIA: int
ERROR_SETMARK_DETECTED: int
ERROR_NO_DATA_DETECTED: int
ERROR_PARTITION_FAILURE: int
ERROR_INVALID_BLOCK_LENGTH: int
ERROR_DEVICE_NOT_PARTITIONED: int
ERROR_UNABLE_TO_LOCK_MEDIA: int
ERROR_UNABLE_TO_UNLOAD_MEDIA: int
ERROR_MEDIA_CHANGED: int
ERROR_BUS_RESET: int
ERROR_NO_MEDIA_IN_DRIVE: int
ERROR_NO_UNICODE_TRANSLATION: int
ERROR_DLL_INIT_FAILED: int
ERROR_SHUTDOWN_IN_PROGRESS: int
ERROR_NO_SHUTDOWN_IN_PROGRESS: int
ERROR_IO_DEVICE: int
ERROR_SERIAL_NO_DEVICE: int
ERROR_IRQ_BUSY: int
ERROR_MORE_WRITES: int
ERROR_COUNTER_TIMEOUT: int
ERROR_FLOPPY_ID_MARK_NOT_FOUND: int
ERROR_FLOPPY_WRONG_CYLINDER: int
ERROR_FLOPPY_UNKNOWN_ERROR: int
ERROR_FLOPPY_BAD_REGISTERS: int
ERROR_DISK_RECALIBRATE_FAILED: int
ERROR_DISK_OPERATION_FAILED: int
ERROR_DISK_RESET_FAILED: int
ERROR_EOM_OVERFLOW: int
ERROR_NOT_ENOUGH_SERVER_MEMORY: int
ERROR_POSSIBLE_DEADLOCK: int
ERROR_MAPPED_ALIGNMENT: int
ERROR_SET_POWER_STATE_VETOED: int
ERROR_SET_POWER_STATE_FAILED: int
ERROR_TOO_MANY_LINKS: int
ERROR_OLD_WIN_VERSION: int
ERROR_APP_WRONG_OS: int
ERROR_SINGLE_INSTANCE_APP: int
ERROR_RMODE_APP: int
ERROR_INVALID_DLL: int
ERROR_NO_ASSOCIATION: int
ERROR_DDE_FAIL: int
ERROR_DLL_NOT_FOUND: int
ERROR_NO_MORE_USER_HANDLES: int
ERROR_MESSAGE_SYNC_ONLY: int
ERROR_SOURCE_ELEMENT_EMPTY: int
ERROR_DESTINATION_ELEMENT_FULL: int
ERROR_ILLEGAL_ELEMENT_ADDRESS: int
ERROR_MAGAZINE_NOT_PRESENT: int
ERROR_DEVICE_REINITIALIZATION_NEEDED: int
ERROR_DEVICE_REQUIRES_CLEANING: int
ERROR_DEVICE_DOOR_OPEN: int
ERROR_DEVICE_NOT_CONNECTED: int
ERROR_NOT_FOUND: int
ERROR_NO_MATCH: int
ERROR_SET_NOT_FOUND: int
ERROR_POINT_NOT_FOUND: int
ERROR_NO_TRACKING_SERVICE: int
ERROR_NO_VOLUME_ID: int
ERROR_CONNECTED_OTHER_PASSWORD: int
ERROR_BAD_USERNAME: int
ERROR_NOT_CONNECTED: int
ERROR_OPEN_FILES: int
ERROR_ACTIVE_CONNECTIONS: int
ERROR_DEVICE_IN_USE: int
ERROR_BAD_DEVICE: int
ERROR_CONNECTION_UNAVAIL: int
ERROR_DEVICE_ALREADY_REMEMBERED: int
ERROR_NO_NET_OR_BAD_PATH: int
ERROR_BAD_PROVIDER: int
ERROR_CANNOT_OPEN_PROFILE: int
ERROR_BAD_PROFILE: int
ERROR_NOT_CONTAINER: int
ERROR_EXTENDED_ERROR: int
ERROR_INVALID_GROUPNAME: int
ERROR_INVALID_COMPUTERNAME: int
ERROR_INVALID_EVENTNAME: int
ERROR_INVALID_DOMAINNAME: int
ERROR_INVALID_SERVICENAME: int
ERROR_INVALID_NETNAME: int
ERROR_INVALID_SHARENAME: int
ERROR_INVALID_PASSWORDNAME: int
ERROR_INVALID_MESSAGENAME: int
ERROR_INVALID_MESSAGEDEST: int
ERROR_SESSION_CREDENTIAL_CONFLICT: int
ERROR_REMOTE_SESSION_LIMIT_EXCEEDED: int
ERROR_DUP_DOMAINNAME: int
ERROR_NO_NETWORK: int
ERROR_CANCELLED: int
ERROR_USER_MAPPED_FILE: int
ERROR_CONNECTION_REFUSED: int
ERROR_GRACEFUL_DISCONNECT: int
ERROR_ADDRESS_ALREADY_ASSOCIATED: int
ERROR_ADDRESS_NOT_ASSOCIATED: int
ERROR_CONNECTION_INVALID: int
ERROR_CONNECTION_ACTIVE: int
ERROR_NETWORK_UNREACHABLE: int
ERROR_HOST_UNREACHABLE: int
ERROR_PROTOCOL_UNREACHABLE: int
ERROR_PORT_UNREACHABLE: int
ERROR_REQUEST_ABORTED: int
ERROR_CONNECTION_ABORTED: int
ERROR_RETRY: int
ERROR_CONNECTION_COUNT_LIMIT: int
ERROR_LOGIN_TIME_RESTRICTION: int
ERROR_LOGIN_WKSTA_RESTRICTION: int
ERROR_INCORRECT_ADDRESS: int
ERROR_ALREADY_REGISTERED: int
ERROR_SERVICE_NOT_FOUND: int
ERROR_NOT_AUTHENTICATED: int
ERROR_NOT_LOGGED_ON: int
ERROR_CONTINUE: int
ERROR_ALREADY_INITIALIZED: int
ERROR_NO_MORE_DEVICES: int
ERROR_NO_SUCH_SITE: int
ERROR_DOMAIN_CONTROLLER_EXISTS: int
ERROR_DS_NOT_INSTALLED: int
ERROR_NOT_ALL_ASSIGNED: int
ERROR_SOME_NOT_MAPPED: int
ERROR_NO_QUOTAS_FOR_ACCOUNT: int
ERROR_LOCAL_USER_SESSION_KEY: int
ERROR_NULL_LM_PASSWORD: int
ERROR_UNKNOWN_REVISION: int
ERROR_REVISION_MISMATCH: int
ERROR_INVALID_OWNER: int
ERROR_INVALID_PRIMARY_GROUP: int
ERROR_NO_IMPERSONATION_TOKEN: int
ERROR_CANT_DISABLE_MANDATORY: int
ERROR_NO_LOGON_SERVERS: int
ERROR_NO_SUCH_LOGON_SESSION: int
ERROR_NO_SUCH_PRIVILEGE: int
ERROR_PRIVILEGE_NOT_HELD: int
ERROR_INVALID_ACCOUNT_NAME: int
ERROR_USER_EXISTS: int
ERROR_NO_SUCH_USER: int
ERROR_GROUP_EXISTS: int
ERROR_NO_SUCH_GROUP: int
ERROR_MEMBER_IN_GROUP: int
ERROR_MEMBER_NOT_IN_GROUP: int
ERROR_LAST_ADMIN: int
ERROR_WRONG_PASSWORD: int
ERROR_ILL_FORMED_PASSWORD: int
ERROR_PASSWORD_RESTRICTION: int
ERROR_LOGON_FAILURE: int
ERROR_ACCOUNT_RESTRICTION: int
ERROR_INVALID_LOGON_HOURS: int
ERROR_INVALID_WORKSTATION: int
ERROR_PASSWORD_EXPIRED: int
ERROR_ACCOUNT_DISABLED: int
ERROR_NONE_MAPPED: int
ERROR_TOO_MANY_LUIDS_REQUESTED: int
ERROR_LUIDS_EXHAUSTED: int
ERROR_INVALID_SUB_AUTHORITY: int
ERROR_INVALID_ACL: int
ERROR_INVALID_SID: int
ERROR_INVALID_SECURITY_DESCR: int
ERROR_BAD_INHERITANCE_ACL: int
ERROR_SERVER_DISABLED: int
ERROR_SERVER_NOT_DISABLED: int
ERROR_INVALID_ID_AUTHORITY: int
ERROR_ALLOTTED_SPACE_EXCEEDED: int
ERROR_INVALID_GROUP_ATTRIBUTES: int
ERROR_BAD_IMPERSONATION_LEVEL: int
ERROR_CANT_OPEN_ANONYMOUS: int
ERROR_BAD_VALIDATION_CLASS: int
ERROR_BAD_TOKEN_TYPE: int
ERROR_NO_SECURITY_ON_OBJECT: int
ERROR_CANT_ACCESS_DOMAIN_INFO: int
ERROR_INVALID_SERVER_STATE: int
ERROR_INVALID_DOMAIN_STATE: int
ERROR_INVALID_DOMAIN_ROLE: int
ERROR_NO_SUCH_DOMAIN: int
ERROR_DOMAIN_EXISTS: int
ERROR_DOMAIN_LIMIT_EXCEEDED: int
ERROR_INTERNAL_DB_CORRUPTION: int
ERROR_INTERNAL_ERROR: int
ERROR_GENERIC_NOT_MAPPED: int
ERROR_BAD_DESCRIPTOR_FORMAT: int
ERROR_NOT_LOGON_PROCESS: int
ERROR_LOGON_SESSION_EXISTS: int
ERROR_NO_SUCH_PACKAGE: int
ERROR_BAD_LOGON_SESSION_STATE: int
ERROR_LOGON_SESSION_COLLISION: int
ERROR_INVALID_LOGON_TYPE: int
ERROR_CANNOT_IMPERSONATE: int
ERROR_RXACT_INVALID_STATE: int
ERROR_RXACT_COMMIT_FAILURE: int
ERROR_SPECIAL_ACCOUNT: int
ERROR_SPECIAL_GROUP: int
ERROR_SPECIAL_USER: int
ERROR_MEMBERS_PRIMARY_GROUP: int
ERROR_TOKEN_ALREADY_IN_USE: int
ERROR_NO_SUCH_ALIAS: int
ERROR_MEMBER_NOT_IN_ALIAS: int
ERROR_MEMBER_IN_ALIAS: int
ERROR_ALIAS_EXISTS: int
ERROR_LOGON_NOT_GRANTED: int
ERROR_TOO_MANY_SECRETS: int
ERROR_SECRET_TOO_LONG: int
ERROR_INTERNAL_DB_ERROR: int
ERROR_TOO_MANY_CONTEXT_IDS: int
ERROR_LOGON_TYPE_NOT_GRANTED: int
ERROR_NT_CROSS_ENCRYPTION_REQUIRED: int
ERROR_NO_SUCH_MEMBER: int
ERROR_INVALID_MEMBER: int
ERROR_TOO_MANY_SIDS: int
ERROR_LM_CROSS_ENCRYPTION_REQUIRED: int
ERROR_NO_INHERITANCE: int
ERROR_FILE_CORRUPT: int
ERROR_DISK_CORRUPT: int
ERROR_NO_USER_SESSION_KEY: int
ERROR_LICENSE_QUOTA_EXCEEDED: int
ERROR_INVALID_WINDOW_HANDLE: int
ERROR_INVALID_MENU_HANDLE: int
ERROR_INVALID_CURSOR_HANDLE: int
ERROR_INVALID_ACCEL_HANDLE: int
ERROR_INVALID_HOOK_HANDLE: int
ERROR_INVALID_DWP_HANDLE: int
ERROR_TLW_WITH_WSCHILD: int
ERROR_CANNOT_FIND_WND_CLASS: int
ERROR_WINDOW_OF_OTHER_THREAD: int
ERROR_HOTKEY_ALREADY_REGISTERED: int
ERROR_CLASS_ALREADY_EXISTS: int
ERROR_CLASS_DOES_NOT_EXIST: int
ERROR_CLASS_HAS_WINDOWS: int
ERROR_INVALID_INDEX: int
ERROR_INVALID_ICON_HANDLE: int
ERROR_PRIVATE_DIALOG_INDEX: int
ERROR_LISTBOX_ID_NOT_FOUND: int
ERROR_NO_WILDCARD_CHARACTERS: int
ERROR_CLIPBOARD_NOT_OPEN: int
ERROR_HOTKEY_NOT_REGISTERED: int
ERROR_WINDOW_NOT_DIALOG: int
ERROR_CONTROL_ID_NOT_FOUND: int
ERROR_INVALID_COMBOBOX_MESSAGE: int
ERROR_WINDOW_NOT_COMBOBOX: int
ERROR_INVALID_EDIT_HEIGHT: int
ERROR_DC_NOT_FOUND: int
ERROR_INVALID_HOOK_FILTER: int
ERROR_INVALID_FILTER_PROC: int
ERROR_HOOK_NEEDS_HMOD: int
ERROR_GLOBAL_ONLY_HOOK: int
ERROR_JOURNAL_HOOK_SET: int
ERROR_HOOK_NOT_INSTALLED: int
ERROR_INVALID_LB_MESSAGE: int
ERROR_SETCOUNT_ON_BAD_LB: int
ERROR_LB_WITHOUT_TABSTOPS: int
ERROR_DESTROY_OBJECT_OF_OTHER_THREAD: int
ERROR_CHILD_WINDOW_MENU: int
ERROR_NO_SYSTEM_MENU: int
ERROR_INVALID_MSGBOX_STYLE: int
ERROR_INVALID_SPI_VALUE: int
ERROR_SCREEN_ALREADY_LOCKED: int
ERROR_HWNDS_HAVE_DIFF_PARENT: int
ERROR_NOT_CHILD_WINDOW: int
ERROR_INVALID_GW_COMMAND: int
ERROR_INVALID_THREAD_ID: int
ERROR_NON_MDICHILD_WINDOW: int
ERROR_POPUP_ALREADY_ACTIVE: int
ERROR_NO_SCROLLBARS: int
ERROR_INVALID_SCROLLBAR_RANGE: int
ERROR_INVALID_SHOWWIN_COMMAND: int
ERROR_NO_SYSTEM_RESOURCES: int
ERROR_NONPAGED_SYSTEM_RESOURCES: int
ERROR_PAGED_SYSTEM_RESOURCES: int
ERROR_WORKING_SET_QUOTA: int
ERROR_PAGEFILE_QUOTA: int
ERROR_COMMITMENT_LIMIT: int
ERROR_MENU_ITEM_NOT_FOUND: int
ERROR_INVALID_KEYBOARD_HANDLE: int
ERROR_HOOK_TYPE_NOT_ALLOWED: int
ERROR_REQUIRES_INTERACTIVE_WINDOWSTATION: int
ERROR_TIMEOUT: int
ERROR_INVALID_MONITOR_HANDLE: int
ERROR_INCORRECT_SIZE: int
ERROR_SYMLINK_CLASS_DISABLED: int
ERROR_SYMLINK_NOT_SUPPORTED: int
ERROR_XML_PARSE_ERROR: int
ERROR_XMLDSIG_ERROR: int
ERROR_RESTART_APPLICATION: int
ERROR_WRONG_COMPARTMENT: int
ERROR_AUTHIP_FAILURE: int
ERROR_EVENTLOG_FILE_CORRUPT: int
ERROR_EVENTLOG_CANT_START: int
ERROR_LOG_FILE_FULL: int
ERROR_EVENTLOG_FILE_CHANGED: int
ERROR_INSTALL_SERVICE: int
ERROR_INSTALL_USEREXIT: int
ERROR_INSTALL_FAILURE: int
ERROR_INSTALL_SUSPEND: int
ERROR_UNKNOWN_PRODUCT: int
ERROR_UNKNOWN_FEATURE: int
ERROR_UNKNOWN_COMPONENT: int
ERROR_UNKNOWN_PROPERTY: int
ERROR_INVALID_HANDLE_STATE: int
ERROR_BAD_CONFIGURATION: int
ERROR_INDEX_ABSENT: int
ERROR_INSTALL_SOURCE_ABSENT: int
ERROR_BAD_DATABASE_VERSION: int
ERROR_PRODUCT_UNINSTALLED: int
ERROR_BAD_QUERY_SYNTAX: int
ERROR_INVALID_FIELD: int
ERROR_DEVICE_REMOVED: int
ERROR_INSTALL_ALREADY_RUNNING: int
ERROR_INSTALL_PACKAGE_OPEN_FAILED: int
ERROR_INSTALL_PACKAGE_INVALID: int
ERROR_INSTALL_UI_FAILURE: int
ERROR_INSTALL_LOG_FAILURE: int
ERROR_INSTALL_LANGUAGE_UNSUPPORTED: int
ERROR_INSTALL_TRANSFORM_FAILURE: int
ERROR_INSTALL_PACKAGE_REJECTED: int
ERROR_FUNCTION_NOT_CALLED: int
ERROR_FUNCTION_FAILED: int
ERROR_INVALID_TABLE: int
ERROR_DATATYPE_MISMATCH: int
ERROR_UNSUPPORTED_TYPE: int
ERROR_CREATE_FAILED: int
ERROR_INSTALL_TEMP_UNWRITABLE: int
ERROR_INSTALL_PLATFORM_UNSUPPORTED: int
ERROR_INSTALL_NOTUSED: int
ERROR_PATCH_PACKAGE_OPEN_FAILED: int
ERROR_PATCH_PACKAGE_INVALID: int
ERROR_PATCH_PACKAGE_UNSUPPORTED: int
ERROR_PRODUCT_VERSION: int
ERROR_INVALID_COMMAND_LINE: int
ERROR_INSTALL_REMOTE_DISALLOWED: int
ERROR_SUCCESS_REBOOT_INITIATED: int
ERROR_PATCH_TARGET_NOT_FOUND: int
ERROR_PATCH_PACKAGE_REJECTED: int
ERROR_INSTALL_TRANSFORM_REJECTED: int
ERROR_INSTALL_REMOTE_PROHIBITED: int
ERROR_PATCH_REMOVAL_UNSUPPORTED: int
ERROR_UNKNOWN_PATCH: int
ERROR_PATCH_NO_SEQUENCE: int
ERROR_PATCH_REMOVAL_DISALLOWED: int
ERROR_INVALID_PATCH_XML: int
ERROR_PATCH_MANAGED_ADVERTISED_PRODUCT: int
ERROR_INSTALL_SERVICE_SAFEBOOT: int
RPC_S_INVALID_STRING_BINDING: int
RPC_S_WRONG_KIND_OF_BINDING: int
RPC_S_INVALID_BINDING: int
RPC_S_PROTSEQ_NOT_SUPPORTED: int
RPC_S_INVALID_RPC_PROTSEQ: int
RPC_S_INVALID_STRING_UUID: int
RPC_S_INVALID_ENDPOINT_FORMAT: int
RPC_S_INVALID_NET_ADDR: int
RPC_S_NO_ENDPOINT_FOUND: int
RPC_S_INVALID_TIMEOUT: int
RPC_S_OBJECT_NOT_FOUND: int
RPC_S_ALREADY_REGISTERED: int
RPC_S_TYPE_ALREADY_REGISTERED: int
RPC_S_ALREADY_LISTENING: int
RPC_S_NO_PROTSEQS_REGISTERED: int
RPC_S_NOT_LISTENING: int
RPC_S_UNKNOWN_MGR_TYPE: int
RPC_S_UNKNOWN_IF: int
RPC_S_NO_BINDINGS: int
RPC_S_NO_PROTSEQS: int
RPC_S_CANT_CREATE_ENDPOINT: int
RPC_S_OUT_OF_RESOURCES: int
RPC_S_SERVER_UNAVAILABLE: int
RPC_S_SERVER_TOO_BUSY: int
RPC_S_INVALID_NETWORK_OPTIONS: int
RPC_S_NO_CALL_ACTIVE: int
RPC_S_CALL_FAILED: int
RPC_S_CALL_FAILED_DNE: int
RPC_S_PROTOCOL_ERROR: int
RPC_S_PROXY_ACCESS_DENIED: int
RPC_S_UNSUPPORTED_TRANS_SYN: int
RPC_S_UNSUPPORTED_TYPE: int
RPC_S_INVALID_TAG: int
RPC_S_INVALID_BOUND: int
RPC_S_NO_ENTRY_NAME: int
RPC_S_INVALID_NAME_SYNTAX: int
RPC_S_UNSUPPORTED_NAME_SYNTAX: int
RPC_S_UUID_NO_ADDRESS: int
RPC_S_DUPLICATE_ENDPOINT: int
RPC_S_UNKNOWN_AUTHN_TYPE: int
RPC_S_MAX_CALLS_TOO_SMALL: int
RPC_S_STRING_TOO_LONG: int
RPC_S_PROTSEQ_NOT_FOUND: int
RPC_S_PROCNUM_OUT_OF_RANGE: int
RPC_S_BINDING_HAS_NO_AUTH: int
RPC_S_UNKNOWN_AUTHN_SERVICE: int
RPC_S_UNKNOWN_AUTHN_LEVEL: int
RPC_S_INVALID_AUTH_IDENTITY: int
RPC_S_UNKNOWN_AUTHZ_SERVICE: int
EPT_S_INVALID_ENTRY: int
EPT_S_CANT_PERFORM_OP: int
EPT_S_NOT_REGISTERED: int
RPC_S_NOTHING_TO_EXPORT: int
RPC_S_INCOMPLETE_NAME: int
RPC_S_INVALID_VERS_OPTION: int
RPC_S_NO_MORE_MEMBERS: int
RPC_S_NOT_ALL_OBJS_UNEXPORTED: int
RPC_S_INTERFACE_NOT_FOUND: int
RPC_S_ENTRY_ALREADY_EXISTS: int
RPC_S_ENTRY_NOT_FOUND: int
RPC_S_NAME_SERVICE_UNAVAILABLE: int
RPC_S_INVALID_NAF_ID: int
RPC_S_CANNOT_SUPPORT: int
RPC_S_NO_CONTEXT_AVAILABLE: int
RPC_S_INTERNAL_ERROR: int
RPC_S_ZERO_DIVIDE: int
RPC_S_ADDRESS_ERROR: int
RPC_S_FP_DIV_ZERO: int
RPC_S_FP_UNDERFLOW: int
RPC_S_FP_OVERFLOW: int
RPC_X_NO_MORE_ENTRIES: int
RPC_X_SS_CHAR_TRANS_OPEN_FAIL: int
RPC_X_SS_CHAR_TRANS_SHORT_FILE: int
RPC_X_SS_IN_NULL_CONTEXT: int
RPC_X_SS_CONTEXT_DAMAGED: int
RPC_X_SS_HANDLES_MISMATCH: int
RPC_X_SS_CANNOT_GET_CALL_HANDLE: int
RPC_X_NULL_REF_POINTER: int
RPC_X_ENUM_VALUE_OUT_OF_RANGE: int
RPC_X_BYTE_COUNT_TOO_SMALL: int
RPC_X_BAD_STUB_DATA: int
ERROR_INVALID_USER_BUFFER: int
ERROR_UNRECOGNIZED_MEDIA: int
ERROR_NO_TRUST_LSA_SECRET: int
ERROR_NO_TRUST_SAM_ACCOUNT: int
ERROR_TRUSTED_DOMAIN_FAILURE: int
ERROR_TRUSTED_RELATIONSHIP_FAILURE: int
ERROR_TRUST_FAILURE: int
RPC_S_CALL_IN_PROGRESS: int
ERROR_NETLOGON_NOT_STARTED: int
ERROR_ACCOUNT_EXPIRED: int
ERROR_REDIRECTOR_HAS_OPEN_HANDLES: int
ERROR_PRINTER_DRIVER_ALREADY_INSTALLED: int
ERROR_UNKNOWN_PORT: int
ERROR_UNKNOWN_PRINTER_DRIVER: int
ERROR_UNKNOWN_PRINTPROCESSOR: int
ERROR_INVALID_SEPARATOR_FILE: int
ERROR_INVALID_PRIORITY: int
ERROR_INVALID_PRINTER_NAME: int
ERROR_PRINTER_ALREADY_EXISTS: int
ERROR_INVALID_PRINTER_COMMAND: int
ERROR_INVALID_DATATYPE: int
ERROR_INVALID_ENVIRONMENT: int
RPC_S_NO_MORE_BINDINGS: int
ERROR_NOLOGON_INTERDOMAIN_TRUST_ACCOUNT: int
ERROR_NOLOGON_WORKSTATION_TRUST_ACCOUNT: int
ERROR_NOLOGON_SERVER_TRUST_ACCOUNT: int
ERROR_DOMAIN_TRUST_INCONSISTENT: int
ERROR_SERVER_HAS_OPEN_HANDLES: int
ERROR_RESOURCE_DATA_NOT_FOUND: int
ERROR_RESOURCE_TYPE_NOT_FOUND: int
ERROR_RESOURCE_NAME_NOT_FOUND: int
ERROR_RESOURCE_LANG_NOT_FOUND: int
ERROR_NOT_ENOUGH_QUOTA: int
RPC_S_NO_INTERFACES: int
RPC_S_CALL_CANCELLED: int
RPC_S_BINDING_INCOMPLETE: int
RPC_S_COMM_FAILURE: int
RPC_S_UNSUPPORTED_AUTHN_LEVEL: int
RPC_S_NO_PRINC_NAME: int
RPC_S_NOT_RPC_ERROR: int
RPC_S_UUID_LOCAL_ONLY: int
RPC_S_SEC_PKG_ERROR: int
RPC_S_NOT_CANCELLED: int
RPC_X_INVALID_ES_ACTION: int
RPC_X_WRONG_ES_VERSION: int
RPC_X_WRONG_STUB_VERSION: int
RPC_X_INVALID_PIPE_OBJECT: int
RPC_X_WRONG_PIPE_ORDER: int
RPC_X_WRONG_PIPE_VERSION: int
RPC_S_GROUP_MEMBER_NOT_FOUND: int
EPT_S_CANT_CREATE: int
RPC_S_INVALID_OBJECT: int
ERROR_INVALID_TIME: int
ERROR_INVALID_FORM_NAME: int
ERROR_INVALID_FORM_SIZE: int
ERROR_ALREADY_WAITING: int
ERROR_PRINTER_DELETED: int
ERROR_INVALID_PRINTER_STATE: int
ERROR_PASSWORD_MUST_CHANGE: int
ERROR_DOMAIN_CONTROLLER_NOT_FOUND: int
ERROR_ACCOUNT_LOCKED_OUT: int
OR_INVALID_OXID: int
OR_INVALID_OID: int
OR_INVALID_SET: int
RPC_S_SEND_INCOMPLETE: int
RPC_S_INVALID_ASYNC_HANDLE: int
RPC_S_INVALID_ASYNC_CALL: int
RPC_X_PIPE_CLOSED: int
RPC_X_PIPE_DISCIPLINE_ERROR: int
RPC_X_PIPE_EMPTY: int
ERROR_NO_SITENAME: int
ERROR_CANT_ACCESS_FILE: int
ERROR_CANT_RESOLVE_FILENAME: int
RPC_S_ENTRY_TYPE_MISMATCH: int
RPC_S_NOT_ALL_OBJS_EXPORTED: int
RPC_S_INTERFACE_NOT_EXPORTED: int
RPC_S_PROFILE_NOT_ADDED: int
RPC_S_PRF_ELT_NOT_ADDED: int
RPC_S_PRF_ELT_NOT_REMOVED: int
RPC_S_GRP_ELT_NOT_ADDED: int
RPC_S_GRP_ELT_NOT_REMOVED: int
ERROR_KM_DRIVER_BLOCKED: int
ERROR_CONTEXT_EXPIRED: int
ERROR_PER_USER_TRUST_QUOTA_EXCEEDED: int
ERROR_ALL_USER_TRUST_QUOTA_EXCEEDED: int
ERROR_USER_DELETE_TRUST_QUOTA_EXCEEDED: int
ERROR_AUTHENTICATION_FIREWALL_FAILED: int
ERROR_REMOTE_PRINT_CONNECTIONS_BLOCKED: int
ERROR_NTLM_BLOCKED: int
ERROR_INVALID_PIXEL_FORMAT: int
ERROR_BAD_DRIVER: int
ERROR_INVALID_WINDOW_STYLE: int
ERROR_METAFILE_NOT_SUPPORTED: int
ERROR_TRANSFORM_NOT_SUPPORTED: int
ERROR_CLIPPING_NOT_SUPPORTED: int
ERROR_INVALID_CMM: int
ERROR_INVALID_PROFILE: int
ERROR_TAG_NOT_FOUND: int
ERROR_TAG_NOT_PRESENT: int
ERROR_DUPLICATE_TAG: int
ERROR_PROFILE_NOT_ASSOCIATED_WITH_DEVICE: int
ERROR_PROFILE_NOT_FOUND: int
ERROR_INVALID_COLORSPACE: int
ERROR_ICM_NOT_ENABLED: int
ERROR_DELETING_ICM_XFORM: int
ERROR_INVALID_TRANSFORM: int
ERROR_COLORSPACE_MISMATCH: int
ERROR_INVALID_COLORINDEX: int
ERROR_PROFILE_DOES_NOT_MATCH_DEVICE: int
ERROR_CONNECTED_OTHER_PASSWORD_DEFAULT: int
ERROR_UNKNOWN_PRINT_MONITOR: int
ERROR_PRINTER_DRIVER_IN_USE: int
ERROR_SPOOL_FILE_NOT_FOUND: int
ERROR_SPL_NO_STARTDOC: int
ERROR_SPL_NO_ADDJOB: int
ERROR_PRINT_PROCESSOR_ALREADY_INSTALLED: int
ERROR_PRINT_MONITOR_ALREADY_INSTALLED: int
ERROR_INVALID_PRINT_MONITOR: int
ERROR_PRINT_MONITOR_IN_USE: int
ERROR_PRINTER_HAS_JOBS_QUEUED: int
ERROR_SUCCESS_REBOOT_REQUIRED: int
ERROR_SUCCESS_RESTART_REQUIRED: int
ERROR_PRINTER_NOT_FOUND: int
ERROR_PRINTER_DRIVER_WARNED: int
ERROR_PRINTER_DRIVER_BLOCKED: int
ERROR_PRINTER_DRIVER_PACKAGE_IN_USE: int
ERROR_CORE_DRIVER_PACKAGE_NOT_FOUND: int
ERROR_FAIL_REBOOT_REQUIRED: int
ERROR_FAIL_REBOOT_INITIATED: int
ERROR_PRINTER_DRIVER_DOWNLOAD_NEEDED: int
ERROR_PRINT_JOB_RESTART_REQUIRED: int
ERROR_IO_REISSUE_AS_CACHED: int
ERROR_WINS_INTERNAL: int
ERROR_CAN_NOT_DEL_LOCAL_WINS: int
ERROR_STATIC_INIT: int
ERROR_INC_BACKUP: int
ERROR_FULL_BACKUP: int
ERROR_REC_NON_EXISTENT: int
ERROR_RPL_NOT_ALLOWED: int
ERROR_DHCP_ADDRESS_CONFLICT: int
ERROR_WMI_GUID_NOT_FOUND: int
ERROR_WMI_INSTANCE_NOT_FOUND: int
ERROR_WMI_ITEMID_NOT_FOUND: int
ERROR_WMI_TRY_AGAIN: int
ERROR_WMI_DP_NOT_FOUND: int
ERROR_WMI_UNRESOLVED_INSTANCE_REF: int
ERROR_WMI_ALREADY_ENABLED: int
ERROR_WMI_GUID_DISCONNECTED: int
ERROR_WMI_SERVER_UNAVAILABLE: int
ERROR_WMI_DP_FAILED: int
ERROR_WMI_INVALID_MOF: int
ERROR_WMI_INVALID_REGINFO: int
ERROR_WMI_ALREADY_DISABLED: int
ERROR_WMI_READ_ONLY: int
ERROR_WMI_SET_FAILURE: int
ERROR_INVALID_MEDIA: int
ERROR_INVALID_LIBRARY: int
ERROR_INVALID_MEDIA_POOL: int
ERROR_DRIVE_MEDIA_MISMATCH: int
ERROR_MEDIA_OFFLINE: int
ERROR_LIBRARY_OFFLINE: int
ERROR_EMPTY: int
ERROR_NOT_EMPTY: int
ERROR_MEDIA_UNAVAILABLE: int
ERROR_RESOURCE_DISABLED: int
ERROR_INVALID_CLEANER: int
ERROR_UNABLE_TO_CLEAN: int
ERROR_OBJECT_NOT_FOUND: int
ERROR_DATABASE_FAILURE: int
ERROR_DATABASE_FULL: int
ERROR_MEDIA_INCOMPATIBLE: int
ERROR_RESOURCE_NOT_PRESENT: int
ERROR_INVALID_OPERATION: int
ERROR_MEDIA_NOT_AVAILABLE: int
ERROR_DEVICE_NOT_AVAILABLE: int
ERROR_REQUEST_REFUSED: int
ERROR_INVALID_DRIVE_OBJECT: int
ERROR_LIBRARY_FULL: int
ERROR_MEDIUM_NOT_ACCESSIBLE: int
ERROR_UNABLE_TO_LOAD_MEDIUM: int
ERROR_UNABLE_TO_INVENTORY_DRIVE: int
ERROR_UNABLE_TO_INVENTORY_SLOT: int
ERROR_UNABLE_TO_INVENTORY_TRANSPORT: int
ERROR_TRANSPORT_FULL: int
ERROR_CONTROLLING_IEPORT: int
ERROR_UNABLE_TO_EJECT_MOUNTED_MEDIA: int
ERROR_CLEANER_SLOT_SET: int
ERROR_CLEANER_SLOT_NOT_SET: int
ERROR_CLEANER_CARTRIDGE_SPENT: int
ERROR_UNEXPECTED_OMID: int
ERROR_CANT_DELETE_LAST_ITEM: int
ERROR_MESSAGE_EXCEEDS_MAX_SIZE: int
ERROR_VOLUME_CONTAINS_SYS_FILES: int
ERROR_INDIGENOUS_TYPE: int
ERROR_NO_SUPPORTING_DRIVES: int
ERROR_CLEANER_CARTRIDGE_INSTALLED: int
ERROR_IEPORT_FULL: int
ERROR_FILE_OFFLINE: int
ERROR_REMOTE_STORAGE_NOT_ACTIVE: int
ERROR_REMOTE_STORAGE_MEDIA_ERROR: int
ERROR_NOT_A_REPARSE_POINT: int
ERROR_REPARSE_ATTRIBUTE_CONFLICT: int
ERROR_INVALID_REPARSE_DATA: int
ERROR_REPARSE_TAG_INVALID: int
ERROR_REPARSE_TAG_MISMATCH: int
ERROR_VOLUME_NOT_SIS_ENABLED: int
ERROR_DEPENDENT_RESOURCE_EXISTS: int
ERROR_DEPENDENCY_NOT_FOUND: int
ERROR_DEPENDENCY_ALREADY_EXISTS: int
ERROR_RESOURCE_NOT_ONLINE: int
ERROR_HOST_NODE_NOT_AVAILABLE: int
ERROR_RESOURCE_NOT_AVAILABLE: int
ERROR_RESOURCE_NOT_FOUND: int
ERROR_SHUTDOWN_CLUSTER: int
ERROR_CANT_EVICT_ACTIVE_NODE: int
ERROR_OBJECT_ALREADY_EXISTS: int
ERROR_OBJECT_IN_LIST: int
ERROR_GROUP_NOT_AVAILABLE: int
ERROR_GROUP_NOT_FOUND: int
ERROR_GROUP_NOT_ONLINE: int
ERROR_HOST_NODE_NOT_RESOURCE_OWNER: int
ERROR_HOST_NODE_NOT_GROUP_OWNER: int
ERROR_RESMON_CREATE_FAILED: int
ERROR_RESMON_ONLINE_FAILED: int
ERROR_RESOURCE_ONLINE: int
ERROR_QUORUM_RESOURCE: int
ERROR_NOT_QUORUM_CAPABLE: int
ERROR_CLUSTER_SHUTTING_DOWN: int
ERROR_INVALID_STATE: int
ERROR_RESOURCE_PROPERTIES_STORED: int
ERROR_NOT_QUORUM_CLASS: int
ERROR_CORE_RESOURCE: int
ERROR_QUORUM_RESOURCE_ONLINE_FAILED: int
ERROR_QUORUMLOG_OPEN_FAILED: int
ERROR_CLUSTERLOG_CORRUPT: int
ERROR_CLUSTERLOG_RECORD_EXCEEDS_MAXSIZE: int
ERROR_CLUSTERLOG_EXCEEDS_MAXSIZE: int
ERROR_CLUSTERLOG_CHKPOINT_NOT_FOUND: int
ERROR_CLUSTERLOG_NOT_ENOUGH_SPACE: int
ERROR_QUORUM_OWNER_ALIVE: int
ERROR_NETWORK_NOT_AVAILABLE: int
ERROR_NODE_NOT_AVAILABLE: int
ERROR_ALL_NODES_NOT_AVAILABLE: int
ERROR_RESOURCE_FAILED: int
ERROR_CLUSTER_INVALID_NODE: int
ERROR_CLUSTER_NODE_EXISTS: int
ERROR_CLUSTER_JOIN_IN_PROGRESS: int
ERROR_CLUSTER_NODE_NOT_FOUND: int
ERROR_CLUSTER_LOCAL_NODE_NOT_FOUND: int
ERROR_CLUSTER_NETWORK_EXISTS: int
ERROR_CLUSTER_NETWORK_NOT_FOUND: int
ERROR_CLUSTER_NETINTERFACE_EXISTS: int
ERROR_CLUSTER_NETINTERFACE_NOT_FOUND: int
ERROR_CLUSTER_INVALID_REQUEST: int
ERROR_CLUSTER_INVALID_NETWORK_PROVIDER: int
ERROR_CLUSTER_NODE_DOWN: int
ERROR_CLUSTER_NODE_UNREACHABLE: int
ERROR_CLUSTER_NODE_NOT_MEMBER: int
ERROR_CLUSTER_JOIN_NOT_IN_PROGRESS: int
ERROR_CLUSTER_INVALID_NETWORK: int
ERROR_CLUSTER_NODE_UP: int
ERROR_CLUSTER_IPADDR_IN_USE: int
ERROR_CLUSTER_NODE_NOT_PAUSED: int
ERROR_CLUSTER_NO_SECURITY_CONTEXT: int
ERROR_CLUSTER_NETWORK_NOT_INTERNAL: int
ERROR_CLUSTER_NODE_ALREADY_UP: int
ERROR_CLUSTER_NODE_ALREADY_DOWN: int
ERROR_CLUSTER_NETWORK_ALREADY_ONLINE: int
ERROR_CLUSTER_NETWORK_ALREADY_OFFLINE: int
ERROR_CLUSTER_NODE_ALREADY_MEMBER: int
ERROR_CLUSTER_LAST_INTERNAL_NETWORK: int
ERROR_CLUSTER_NETWORK_HAS_DEPENDENTS: int
ERROR_INVALID_OPERATION_ON_QUORUM: int
ERROR_DEPENDENCY_NOT_ALLOWED: int
ERROR_CLUSTER_NODE_PAUSED: int
ERROR_NODE_CANT_HOST_RESOURCE: int
ERROR_CLUSTER_NODE_NOT_READY: int
ERROR_CLUSTER_NODE_SHUTTING_DOWN: int
ERROR_CLUSTER_JOIN_ABORTED: int
ERROR_CLUSTER_INCOMPATIBLE_VERSIONS: int
ERROR_CLUSTER_MAXNUM_OF_RESOURCES_EXCEEDED: int
ERROR_CLUSTER_SYSTEM_CONFIG_CHANGED: int
ERROR_CLUSTER_RESOURCE_TYPE_NOT_FOUND: int
ERROR_CLUSTER_RESTYPE_NOT_SUPPORTED: int
ERROR_CLUSTER_RESNAME_NOT_FOUND: int
ERROR_CLUSTER_NO_RPC_PACKAGES_REGISTERED: int
ERROR_CLUSTER_OWNER_NOT_IN_PREFLIST: int
ERROR_CLUSTER_DATABASE_SEQMISMATCH: int
ERROR_RESMON_INVALID_STATE: int
ERROR_CLUSTER_GUM_NOT_LOCKER: int
ERROR_QUORUM_DISK_NOT_FOUND: int
ERROR_DATABASE_BACKUP_CORRUPT: int
ERROR_CLUSTER_NODE_ALREADY_HAS_DFS_ROOT: int
ERROR_RESOURCE_PROPERTY_UNCHANGEABLE: int
ERROR_CLUSTER_MEMBERSHIP_INVALID_STATE: int
ERROR_CLUSTER_QUORUMLOG_NOT_FOUND: int
ERROR_CLUSTER_MEMBERSHIP_HALT: int
ERROR_CLUSTER_INSTANCE_ID_MISMATCH: int
ERROR_CLUSTER_NETWORK_NOT_FOUND_FOR_IP: int
ERROR_CLUSTER_PROPERTY_DATA_TYPE_MISMATCH: int
ERROR_CLUSTER_EVICT_WITHOUT_CLEANUP: int
ERROR_CLUSTER_PARAMETER_MISMATCH: int
ERROR_NODE_CANNOT_BE_CLUSTERED: int
ERROR_CLUSTER_WRONG_OS_VERSION: int
ERROR_CLUSTER_CANT_CREATE_DUP_CLUSTER_NAME: int
ERROR_CLUSCFG_ALREADY_COMMITTED: int
ERROR_CLUSCFG_ROLLBACK_FAILED: int
ERROR_CLUSCFG_SYSTEM_DISK_DRIVE_LETTER_CONFLICT: int
ERROR_CLUSTER_OLD_VERSION: int
ERROR_CLUSTER_MISMATCHED_COMPUTER_ACCT_NAME: int
ERROR_CLUSTER_NO_NET_ADAPTERS: int
ERROR_CLUSTER_POISONED: int
ERROR_CLUSTER_GROUP_MOVING: int
ERROR_CLUSTER_RESOURCE_TYPE_BUSY: int
ERROR_RESOURCE_CALL_TIMED_OUT: int
ERROR_INVALID_CLUSTER_IPV6_ADDRESS: int
ERROR_CLUSTER_INTERNAL_INVALID_FUNCTION: int
ERROR_CLUSTER_PARAMETER_OUT_OF_BOUNDS: int
ERROR_CLUSTER_PARTIAL_SEND: int
ERROR_CLUSTER_REGISTRY_INVALID_FUNCTION: int
ERROR_CLUSTER_INVALID_STRING_TERMINATION: int
ERROR_CLUSTER_INVALID_STRING_FORMAT: int
ERROR_CLUSTER_DATABASE_TRANSACTION_IN_PROGRESS: int
ERROR_CLUSTER_DATABASE_TRANSACTION_NOT_IN_PROGRESS: int
ERROR_CLUSTER_NULL_DATA: int
ERROR_CLUSTER_PARTIAL_READ: int
ERROR_CLUSTER_PARTIAL_WRITE: int
ERROR_CLUSTER_CANT_DESERIALIZE_DATA: int
ERROR_DEPENDENT_RESOURCE_PROPERTY_CONFLICT: int
ERROR_CLUSTER_NO_QUORUM: int
ERROR_CLUSTER_INVALID_IPV6_NETWORK: int
ERROR_CLUSTER_INVALID_IPV6_TUNNEL_NETWORK: int
ERROR_QUORUM_NOT_ALLOWED_IN_THIS_GROUP: int
ERROR_DEPENDENCY_TREE_TOO_COMPLEX: int
ERROR_EXCEPTION_IN_RESOURCE_CALL: int
ERROR_CLUSTER_RHS_FAILED_INITIALIZATION: int
ERROR_CLUSTER_NOT_INSTALLED: int
ERROR_CLUSTER_RESOURCES_MUST_BE_ONLINE_ON_THE_SAME_NODE: int
ERROR_ENCRYPTION_FAILED: int
ERROR_DECRYPTION_FAILED: int
ERROR_FILE_ENCRYPTED: int
ERROR_NO_RECOVERY_POLICY: int
ERROR_NO_EFS: int
ERROR_WRONG_EFS: int
ERROR_NO_USER_KEYS: int
ERROR_FILE_NOT_ENCRYPTED: int
ERROR_NOT_EXPORT_FORMAT: int
ERROR_FILE_READ_ONLY: int
ERROR_DIR_EFS_DISALLOWED: int
ERROR_EFS_SERVER_NOT_TRUSTED: int
ERROR_BAD_RECOVERY_POLICY: int
ERROR_EFS_ALG_BLOB_TOO_BIG: int
ERROR_VOLUME_NOT_SUPPORT_EFS: int
ERROR_EFS_DISABLED: int
ERROR_EFS_VERSION_NOT_SUPPORT: int
ERROR_CS_ENCRYPTION_INVALID_SERVER_RESPONSE: int
ERROR_CS_ENCRYPTION_UNSUPPORTED_SERVER: int
ERROR_CS_ENCRYPTION_EXISTING_ENCRYPTED_FILE: int
ERROR_CS_ENCRYPTION_NEW_ENCRYPTED_FILE: int
ERROR_CS_ENCRYPTION_FILE_NOT_CSE: int
ERROR_NO_BROWSER_SERVERS_FOUND: int
ERROR_LOG_SECTOR_INVALID: int
ERROR_LOG_SECTOR_PARITY_INVALID: int
ERROR_LOG_SECTOR_REMAPPED: int
ERROR_LOG_BLOCK_INCOMPLETE: int
ERROR_LOG_INVALID_RANGE: int
ERROR_LOG_BLOCKS_EXHAUSTED: int
ERROR_LOG_READ_CONTEXT_INVALID: int
ERROR_LOG_RESTART_INVALID: int
ERROR_LOG_BLOCK_VERSION: int
ERROR_LOG_BLOCK_INVALID: int
ERROR_LOG_READ_MODE_INVALID: int
ERROR_LOG_NO_RESTART: int
ERROR_LOG_METADATA_CORRUPT: int
ERROR_LOG_METADATA_INVALID: int
ERROR_LOG_METADATA_INCONSISTENT: int
ERROR_LOG_RESERVATION_INVALID: int
ERROR_LOG_CANT_DELETE: int
ERROR_LOG_CONTAINER_LIMIT_EXCEEDED: int
ERROR_LOG_START_OF_LOG: int
ERROR_LOG_POLICY_ALREADY_INSTALLED: int
ERROR_LOG_POLICY_NOT_INSTALLED: int
ERROR_LOG_POLICY_INVALID: int
ERROR_LOG_POLICY_CONFLICT: int
ERROR_LOG_PINNED_ARCHIVE_TAIL: int
ERROR_LOG_RECORD_NONEXISTENT: int
ERROR_LOG_RECORDS_RESERVED_INVALID: int
ERROR_LOG_SPACE_RESERVED_INVALID: int
ERROR_LOG_TAIL_INVALID: int
ERROR_LOG_FULL: int
ERROR_COULD_NOT_RESIZE_LOG: int
ERROR_LOG_MULTIPLEXED: int
ERROR_LOG_DEDICATED: int
ERROR_LOG_ARCHIVE_NOT_IN_PROGRESS: int
ERROR_LOG_ARCHIVE_IN_PROGRESS: int
ERROR_LOG_EPHEMERAL: int
ERROR_LOG_NOT_ENOUGH_CONTAINERS: int
ERROR_LOG_CLIENT_ALREADY_REGISTERED: int
ERROR_LOG_CLIENT_NOT_REGISTERED: int
ERROR_LOG_FULL_HANDLER_IN_PROGRESS: int
ERROR_LOG_CONTAINER_READ_FAILED: int
ERROR_LOG_CONTAINER_WRITE_FAILED: int
ERROR_LOG_CONTAINER_OPEN_FAILED: int
ERROR_LOG_CONTAINER_STATE_INVALID: int
ERROR_LOG_STATE_INVALID: int
ERROR_LOG_PINNED: int
ERROR_LOG_METADATA_FLUSH_FAILED: int
ERROR_LOG_INCONSISTENT_SECURITY: int
ERROR_LOG_APPENDED_FLUSH_FAILED: int
ERROR_LOG_PINNED_RESERVATION: int
ERROR_INVALID_TRANSACTION: int
ERROR_TRANSACTION_NOT_ACTIVE: int
ERROR_TRANSACTION_REQUEST_NOT_VALID: int
ERROR_TRANSACTION_NOT_REQUESTED: int
ERROR_TRANSACTION_ALREADY_ABORTED: int
ERROR_TRANSACTION_ALREADY_COMMITTED: int
ERROR_TM_INITIALIZATION_FAILED: int
ERROR_RESOURCEMANAGER_READ_ONLY: int
ERROR_TRANSACTION_NOT_JOINED: int
ERROR_TRANSACTION_SUPERIOR_EXISTS: int
ERROR_CRM_PROTOCOL_ALREADY_EXISTS: int
ERROR_TRANSACTION_PROPAGATION_FAILED: int
ERROR_CRM_PROTOCOL_NOT_FOUND: int
ERROR_TRANSACTION_INVALID_MARSHALL_BUFFER: int
ERROR_CURRENT_TRANSACTION_NOT_VALID: int
ERROR_TRANSACTION_NOT_FOUND: int
ERROR_RESOURCEMANAGER_NOT_FOUND: int
ERROR_ENLISTMENT_NOT_FOUND: int
ERROR_TRANSACTIONMANAGER_NOT_FOUND: int
ERROR_TRANSACTIONMANAGER_NOT_ONLINE: int
ERROR_TRANSACTIONMANAGER_RECOVERY_NAME_COLLISION: int
ERROR_TRANSACTION_NOT_ROOT: int
ERROR_TRANSACTION_OBJECT_EXPIRED: int
ERROR_TRANSACTION_RESPONSE_NOT_ENLISTED: int
ERROR_TRANSACTION_RECORD_TOO_LONG: int
ERROR_IMPLICIT_TRANSACTION_NOT_SUPPORTED: int
ERROR_TRANSACTION_INTEGRITY_VIOLATED: int
ERROR_TRANSACTIONAL_CONFLICT: int
ERROR_RM_NOT_ACTIVE: int
ERROR_RM_METADATA_CORRUPT: int
ERROR_DIRECTORY_NOT_RM: int
ERROR_TRANSACTIONS_UNSUPPORTED_REMOTE: int
ERROR_LOG_RESIZE_INVALID_SIZE: int
ERROR_OBJECT_NO_LONGER_EXISTS: int
ERROR_STREAM_MINIVERSION_NOT_FOUND: int
ERROR_STREAM_MINIVERSION_NOT_VALID: int
ERROR_MINIVERSION_INACCESSIBLE_FROM_SPECIFIED_TRANSACTION: int
ERROR_CANT_OPEN_MINIVERSION_WITH_MODIFY_INTENT: int
ERROR_CANT_CREATE_MORE_STREAM_MINIVERSIONS: int
ERROR_REMOTE_FILE_VERSION_MISMATCH: int
ERROR_HANDLE_NO_LONGER_VALID: int
ERROR_NO_TXF_METADATA: int
ERROR_LOG_CORRUPTION_DETECTED: int
ERROR_CANT_RECOVER_WITH_HANDLE_OPEN: int
ERROR_RM_DISCONNECTED: int
ERROR_ENLISTMENT_NOT_SUPERIOR: int
ERROR_RECOVERY_NOT_NEEDED: int
ERROR_RM_ALREADY_STARTED: int
ERROR_FILE_IDENTITY_NOT_PERSISTENT: int
ERROR_CANT_BREAK_TRANSACTIONAL_DEPENDENCY: int
ERROR_CANT_CROSS_RM_BOUNDARY: int
ERROR_TXF_DIR_NOT_EMPTY: int
ERROR_INDOUBT_TRANSACTIONS_EXIST: int
ERROR_TM_VOLATILE: int
ERROR_ROLLBACK_TIMER_EXPIRED: int
ERROR_TXF_ATTRIBUTE_CORRUPT: int
ERROR_EFS_NOT_ALLOWED_IN_TRANSACTION: int
ERROR_TRANSACTIONAL_OPEN_NOT_ALLOWED: int
ERROR_LOG_GROWTH_FAILED: int
ERROR_TRANSACTED_MAPPING_UNSUPPORTED_REMOTE: int
ERROR_TXF_METADATA_ALREADY_PRESENT: int
ERROR_TRANSACTION_SCOPE_CALLBACKS_NOT_SET: int
ERROR_TRANSACTION_REQUIRED_PROMOTION: int
ERROR_CANNOT_EXECUTE_FILE_IN_TRANSACTION: int
ERROR_TRANSACTIONS_NOT_FROZEN: int
ERROR_TRANSACTION_FREEZE_IN_PROGRESS: int
ERROR_NOT_SNAPSHOT_VOLUME: int
ERROR_NO_SAVEPOINT_WITH_OPEN_FILES: int
ERROR_DATA_LOST_REPAIR: int
ERROR_SPARSE_NOT_ALLOWED_IN_TRANSACTION: int
ERROR_TM_IDENTITY_MISMATCH: int
ERROR_FLOATED_SECTION: int
ERROR_CANNOT_ACCEPT_TRANSACTED_WORK: int
ERROR_CANNOT_ABORT_TRANSACTIONS: int
ERROR_BAD_CLUSTERS: int
ERROR_COMPRESSION_NOT_ALLOWED_IN_TRANSACTION: int
ERROR_VOLUME_DIRTY: int
ERROR_NO_LINK_TRACKING_IN_TRANSACTION: int
ERROR_OPERATION_NOT_SUPPORTED_IN_TRANSACTION: int
ERROR_CTX_WINSTATION_NAME_INVALID: int
ERROR_CTX_INVALID_PD: int
ERROR_CTX_PD_NOT_FOUND: int
ERROR_CTX_WD_NOT_FOUND: int
ERROR_CTX_CANNOT_MAKE_EVENTLOG_ENTRY: int
ERROR_CTX_SERVICE_NAME_COLLISION: int
ERROR_CTX_CLOSE_PENDING: int
ERROR_CTX_NO_OUTBUF: int
ERROR_CTX_MODEM_INF_NOT_FOUND: int
ERROR_CTX_INVALID_MODEMNAME: int
ERROR_CTX_MODEM_RESPONSE_ERROR: int
ERROR_CTX_MODEM_RESPONSE_TIMEOUT: int
ERROR_CTX_MODEM_RESPONSE_NO_CARRIER: int
ERROR_CTX_MODEM_RESPONSE_NO_DIALTONE: int
ERROR_CTX_MODEM_RESPONSE_BUSY: int
ERROR_CTX_MODEM_RESPONSE_VOICE: int
ERROR_CTX_TD_ERROR: int
ERROR_CTX_WINSTATION_NOT_FOUND: int
ERROR_CTX_WINSTATION_ALREADY_EXISTS: int
ERROR_CTX_WINSTATION_BUSY: int
ERROR_CTX_BAD_VIDEO_MODE: int
ERROR_CTX_GRAPHICS_INVALID: int
ERROR_CTX_LOGON_DISABLED: int
ERROR_CTX_NOT_CONSOLE: int
ERROR_CTX_CLIENT_QUERY_TIMEOUT: int
ERROR_CTX_CONSOLE_DISCONNECT: int
ERROR_CTX_CONSOLE_CONNECT: int
ERROR_CTX_SHADOW_DENIED: int
ERROR_CTX_WINSTATION_ACCESS_DENIED: int
ERROR_CTX_INVALID_WD: int
ERROR_CTX_SHADOW_INVALID: int
ERROR_CTX_SHADOW_DISABLED: int
ERROR_CTX_CLIENT_LICENSE_IN_USE: int
ERROR_CTX_CLIENT_LICENSE_NOT_SET: int
ERROR_CTX_LICENSE_NOT_AVAILABLE: int
ERROR_CTX_LICENSE_CLIENT_INVALID: int
ERROR_CTX_LICENSE_EXPIRED: int
ERROR_CTX_SHADOW_NOT_RUNNING: int
ERROR_CTX_SHADOW_ENDED_BY_MODE_CHANGE: int
ERROR_ACTIVATION_COUNT_EXCEEDED: int
ERROR_CTX_WINSTATIONS_DISABLED: int
ERROR_CTX_ENCRYPTION_LEVEL_REQUIRED: int
ERROR_CTX_SESSION_IN_USE: int
ERROR_CTX_NO_FORCE_LOGOFF: int
ERROR_CTX_ACCOUNT_RESTRICTION: int
ERROR_RDP_PROTOCOL_ERROR: int
ERROR_CTX_CDM_CONNECT: int
ERROR_CTX_CDM_DISCONNECT: int
ERROR_CTX_SECURITY_LAYER_ERROR: int
ERROR_TS_INCOMPATIBLE_SESSIONS: int
FRS_ERR_INVALID_API_SEQUENCE: int
FRS_ERR_STARTING_SERVICE: int
FRS_ERR_STOPPING_SERVICE: int
FRS_ERR_INTERNAL_API: int
FRS_ERR_INTERNAL: int
FRS_ERR_SERVICE_COMM: int
FRS_ERR_INSUFFICIENT_PRIV: int
FRS_ERR_AUTHENTICATION: int
FRS_ERR_PARENT_INSUFFICIENT_PRIV: int
FRS_ERR_PARENT_AUTHENTICATION: int
FRS_ERR_CHILD_TO_PARENT_COMM: int
FRS_ERR_PARENT_TO_CHILD_COMM: int
FRS_ERR_SYSVOL_POPULATE: int
FRS_ERR_SYSVOL_POPULATE_TIMEOUT: int
FRS_ERR_SYSVOL_IS_BUSY: int
FRS_ERR_SYSVOL_DEMOTE: int
FRS_ERR_INVALID_SERVICE_PARAMETER: int
DS_S_SUCCESS: int
ERROR_DS_MEMBERSHIP_EVALUATED_LOCALLY: int
ERROR_DS_NO_ATTRIBUTE_OR_VALUE: int
ERROR_DS_INVALID_ATTRIBUTE_SYNTAX: int
ERROR_DS_ATTRIBUTE_TYPE_UNDEFINED: int
ERROR_DS_ATTRIBUTE_OR_VALUE_EXISTS: int
ERROR_DS_BUSY: int
ERROR_DS_UNAVAILABLE: int
ERROR_DS_NO_RIDS_ALLOCATED: int
ERROR_DS_NO_MORE_RIDS: int
ERROR_DS_INCORRECT_ROLE_OWNER: int
ERROR_DS_RIDMGR_INIT_ERROR: int
ERROR_DS_OBJ_CLASS_VIOLATION: int
ERROR_DS_CANT_ON_NON_LEAF: int
ERROR_DS_CANT_ON_RDN: int
ERROR_DS_CANT_MOD_OBJ_CLASS: int
ERROR_DS_CROSS_DOM_MOVE_ERROR: int
ERROR_DS_GC_NOT_AVAILABLE: int
ERROR_SHARED_POLICY: int
ERROR_POLICY_OBJECT_NOT_FOUND: int
ERROR_POLICY_ONLY_IN_DS: int
ERROR_PROMOTION_ACTIVE: int
ERROR_NO_PROMOTION_ACTIVE: int
ERROR_DS_OPERATIONS_ERROR: int
ERROR_DS_PROTOCOL_ERROR: int
ERROR_DS_TIMELIMIT_EXCEEDED: int
ERROR_DS_SIZELIMIT_EXCEEDED: int
ERROR_DS_ADMIN_LIMIT_EXCEEDED: int
ERROR_DS_COMPARE_FALSE: int
ERROR_DS_COMPARE_TRUE: int
ERROR_DS_AUTH_METHOD_NOT_SUPPORTED: int
ERROR_DS_STRONG_AUTH_REQUIRED: int
ERROR_DS_INAPPROPRIATE_AUTH: int
ERROR_DS_AUTH_UNKNOWN: int
ERROR_DS_REFERRAL: int
ERROR_DS_UNAVAILABLE_CRIT_EXTENSION: int
ERROR_DS_CONFIDENTIALITY_REQUIRED: int
ERROR_DS_INAPPROPRIATE_MATCHING: int
ERROR_DS_CONSTRAINT_VIOLATION: int
ERROR_DS_NO_SUCH_OBJECT: int
ERROR_DS_ALIAS_PROBLEM: int
ERROR_DS_INVALID_DN_SYNTAX: int
ERROR_DS_IS_LEAF: int
ERROR_DS_ALIAS_DEREF_PROBLEM: int
ERROR_DS_UNWILLING_TO_PERFORM: int
ERROR_DS_LOOP_DETECT: int
ERROR_DS_NAMING_VIOLATION: int
ERROR_DS_OBJECT_RESULTS_TOO_LARGE: int
ERROR_DS_AFFECTS_MULTIPLE_DSAS: int
ERROR_DS_SERVER_DOWN: int
ERROR_DS_LOCAL_ERROR: int
ERROR_DS_ENCODING_ERROR: int
ERROR_DS_DECODING_ERROR: int
ERROR_DS_FILTER_UNKNOWN: int
ERROR_DS_PARAM_ERROR: int
ERROR_DS_NOT_SUPPORTED: int
ERROR_DS_NO_RESULTS_RETURNED: int
ERROR_DS_CONTROL_NOT_FOUND: int
ERROR_DS_CLIENT_LOOP: int
ERROR_DS_REFERRAL_LIMIT_EXCEEDED: int
ERROR_DS_SORT_CONTROL_MISSING: int
ERROR_DS_OFFSET_RANGE_ERROR: int
ERROR_DS_ROOT_MUST_BE_NC: int
ERROR_DS_ADD_REPLICA_INHIBITED: int
ERROR_DS_ATT_NOT_DEF_IN_SCHEMA: int
ERROR_DS_MAX_OBJ_SIZE_EXCEEDED: int
ERROR_DS_OBJ_STRING_NAME_EXISTS: int
ERROR_DS_NO_RDN_DEFINED_IN_SCHEMA: int
ERROR_DS_RDN_DOESNT_MATCH_SCHEMA: int
ERROR_DS_NO_REQUESTED_ATTS_FOUND: int
ERROR_DS_USER_BUFFER_TO_SMALL: int
ERROR_DS_ATT_IS_NOT_ON_OBJ: int
ERROR_DS_ILLEGAL_MOD_OPERATION: int
ERROR_DS_OBJ_TOO_LARGE: int
ERROR_DS_BAD_INSTANCE_TYPE: int
ERROR_DS_MASTERDSA_REQUIRED: int
ERROR_DS_OBJECT_CLASS_REQUIRED: int
ERROR_DS_MISSING_REQUIRED_ATT: int
ERROR_DS_ATT_NOT_DEF_FOR_CLASS: int
ERROR_DS_ATT_ALREADY_EXISTS: int
ERROR_DS_CANT_ADD_ATT_VALUES: int
ERROR_DS_SINGLE_VALUE_CONSTRAINT: int
ERROR_DS_RANGE_CONSTRAINT: int
ERROR_DS_ATT_VAL_ALREADY_EXISTS: int
ERROR_DS_CANT_REM_MISSING_ATT: int
ERROR_DS_CANT_REM_MISSING_ATT_VAL: int
ERROR_DS_ROOT_CANT_BE_SUBREF: int
ERROR_DS_NO_CHAINING: int
ERROR_DS_NO_CHAINED_EVAL: int
ERROR_DS_NO_PARENT_OBJECT: int
ERROR_DS_PARENT_IS_AN_ALIAS: int
ERROR_DS_CANT_MIX_MASTER_AND_REPS: int
ERROR_DS_CHILDREN_EXIST: int
ERROR_DS_OBJ_NOT_FOUND: int
ERROR_DS_ALIASED_OBJ_MISSING: int
ERROR_DS_BAD_NAME_SYNTAX: int
ERROR_DS_ALIAS_POINTS_TO_ALIAS: int
ERROR_DS_CANT_DEREF_ALIAS: int
ERROR_DS_OUT_OF_SCOPE: int
ERROR_DS_OBJECT_BEING_REMOVED: int
ERROR_DS_CANT_DELETE_DSA_OBJ: int
ERROR_DS_GENERIC_ERROR: int
ERROR_DS_DSA_MUST_BE_INT_MASTER: int
ERROR_DS_CLASS_NOT_DSA: int
ERROR_DS_INSUFF_ACCESS_RIGHTS: int
ERROR_DS_ILLEGAL_SUPERIOR: int
ERROR_DS_ATTRIBUTE_OWNED_BY_SAM: int
ERROR_DS_NAME_TOO_MANY_PARTS: int
ERROR_DS_NAME_TOO_LONG: int
ERROR_DS_NAME_VALUE_TOO_LONG: int
ERROR_DS_NAME_UNPARSEABLE: int
ERROR_DS_NAME_TYPE_UNKNOWN: int
ERROR_DS_NOT_AN_OBJECT: int
ERROR_DS_SEC_DESC_TOO_SHORT: int
ERROR_DS_SEC_DESC_INVALID: int
ERROR_DS_NO_DELETED_NAME: int
ERROR_DS_SUBREF_MUST_HAVE_PARENT: int
ERROR_DS_NCNAME_MUST_BE_NC: int
ERROR_DS_CANT_ADD_SYSTEM_ONLY: int
ERROR_DS_CLASS_MUST_BE_CONCRETE: int
ERROR_DS_INVALID_DMD: int
ERROR_DS_OBJ_GUID_EXISTS: int
ERROR_DS_NOT_ON_BACKLINK: int
ERROR_DS_NO_CROSSREF_FOR_NC: int
ERROR_DS_SHUTTING_DOWN: int
ERROR_DS_UNKNOWN_OPERATION: int
ERROR_DS_INVALID_ROLE_OWNER: int
ERROR_DS_COULDNT_CONTACT_FSMO: int
ERROR_DS_CROSS_NC_DN_RENAME: int
ERROR_DS_CANT_MOD_SYSTEM_ONLY: int
ERROR_DS_REPLICATOR_ONLY: int
ERROR_DS_OBJ_CLASS_NOT_DEFINED: int
ERROR_DS_OBJ_CLASS_NOT_SUBCLASS: int
ERROR_DS_NAME_REFERENCE_INVALID: int
ERROR_DS_CROSS_REF_EXISTS: int
ERROR_DS_CANT_DEL_MASTER_CROSSREF: int
ERROR_DS_SUBTREE_NOTIFY_NOT_NC_HEAD: int
ERROR_DS_NOTIFY_FILTER_TOO_COMPLEX: int
ERROR_DS_DUP_RDN: int
ERROR_DS_DUP_OID: int
ERROR_DS_DUP_MAPI_ID: int
ERROR_DS_DUP_SCHEMA_ID_GUID: int
ERROR_DS_DUP_LDAP_DISPLAY_NAME: int
ERROR_DS_SEMANTIC_ATT_TEST: int
ERROR_DS_SYNTAX_MISMATCH: int
ERROR_DS_EXISTS_IN_MUST_HAVE: int
ERROR_DS_EXISTS_IN_MAY_HAVE: int
ERROR_DS_NONEXISTENT_MAY_HAVE: int
ERROR_DS_NONEXISTENT_MUST_HAVE: int
ERROR_DS_AUX_CLS_TEST_FAIL: int
ERROR_DS_NONEXISTENT_POSS_SUP: int
ERROR_DS_SUB_CLS_TEST_FAIL: int
ERROR_DS_BAD_RDN_ATT_ID_SYNTAX: int
ERROR_DS_EXISTS_IN_AUX_CLS: int
ERROR_DS_EXISTS_IN_SUB_CLS: int
ERROR_DS_EXISTS_IN_POSS_SUP: int
ERROR_DS_RECALCSCHEMA_FAILED: int
ERROR_DS_TREE_DELETE_NOT_FINISHED: int
ERROR_DS_CANT_DELETE: int
ERROR_DS_ATT_SCHEMA_REQ_ID: int
ERROR_DS_BAD_ATT_SCHEMA_SYNTAX: int
ERROR_DS_CANT_CACHE_ATT: int
ERROR_DS_CANT_CACHE_CLASS: int
ERROR_DS_CANT_REMOVE_ATT_CACHE: int
ERROR_DS_CANT_REMOVE_CLASS_CACHE: int
ERROR_DS_CANT_RETRIEVE_DN: int
ERROR_DS_MISSING_SUPREF: int
ERROR_DS_CANT_RETRIEVE_INSTANCE: int
ERROR_DS_CODE_INCONSISTENCY: int
ERROR_DS_DATABASE_ERROR: int
ERROR_DS_GOVERNSID_MISSING: int
ERROR_DS_MISSING_EXPECTED_ATT: int
ERROR_DS_NCNAME_MISSING_CR_REF: int
ERROR_DS_SECURITY_CHECKING_ERROR: int
ERROR_DS_SCHEMA_NOT_LOADED: int
ERROR_DS_SCHEMA_ALLOC_FAILED: int
ERROR_DS_ATT_SCHEMA_REQ_SYNTAX: int
ERROR_DS_GCVERIFY_ERROR: int
ERROR_DS_DRA_SCHEMA_MISMATCH: int
ERROR_DS_CANT_FIND_DSA_OBJ: int
ERROR_DS_CANT_FIND_EXPECTED_NC: int
ERROR_DS_CANT_FIND_NC_IN_CACHE: int
ERROR_DS_CANT_RETRIEVE_CHILD: int
ERROR_DS_SECURITY_ILLEGAL_MODIFY: int
ERROR_DS_CANT_REPLACE_HIDDEN_REC: int
ERROR_DS_BAD_HIERARCHY_FILE: int
ERROR_DS_BUILD_HIERARCHY_TABLE_FAILED: int
ERROR_DS_CONFIG_PARAM_MISSING: int
ERROR_DS_COUNTING_AB_INDICES_FAILED: int
ERROR_DS_HIERARCHY_TABLE_MALLOC_FAILED: int
ERROR_DS_INTERNAL_FAILURE: int
ERROR_DS_UNKNOWN_ERROR: int
ERROR_DS_ROOT_REQUIRES_CLASS_TOP: int
ERROR_DS_REFUSING_FSMO_ROLES: int
ERROR_DS_MISSING_FSMO_SETTINGS: int
ERROR_DS_UNABLE_TO_SURRENDER_ROLES: int
ERROR_DS_DRA_GENERIC: int
ERROR_DS_DRA_INVALID_PARAMETER: int
ERROR_DS_DRA_BUSY: int
ERROR_DS_DRA_BAD_DN: int
ERROR_DS_DRA_BAD_NC: int
ERROR_DS_DRA_DN_EXISTS: int
ERROR_DS_DRA_INTERNAL_ERROR: int
ERROR_DS_DRA_INCONSISTENT_DIT: int
ERROR_DS_DRA_CONNECTION_FAILED: int
ERROR_DS_DRA_BAD_INSTANCE_TYPE: int
ERROR_DS_DRA_OUT_OF_MEM: int
ERROR_DS_DRA_MAIL_PROBLEM: int
ERROR_DS_DRA_REF_ALREADY_EXISTS: int
ERROR_DS_DRA_REF_NOT_FOUND: int
ERROR_DS_DRA_OBJ_IS_REP_SOURCE: int
ERROR_DS_DRA_DB_ERROR: int
ERROR_DS_DRA_NO_REPLICA: int
ERROR_DS_DRA_ACCESS_DENIED: int
ERROR_DS_DRA_NOT_SUPPORTED: int
ERROR_DS_DRA_RPC_CANCELLED: int
ERROR_DS_DRA_SOURCE_DISABLED: int
ERROR_DS_DRA_SINK_DISABLED: int
ERROR_DS_DRA_NAME_COLLISION: int
ERROR_DS_DRA_SOURCE_REINSTALLED: int
ERROR_DS_DRA_MISSING_PARENT: int
ERROR_DS_DRA_PREEMPTED: int
ERROR_DS_DRA_ABANDON_SYNC: int
ERROR_DS_DRA_SHUTDOWN: int
ERROR_DS_DRA_INCOMPATIBLE_PARTIAL_SET: int
ERROR_DS_DRA_SOURCE_IS_PARTIAL_REPLICA: int
ERROR_DS_DRA_EXTN_CONNECTION_FAILED: int
ERROR_DS_INSTALL_SCHEMA_MISMATCH: int
ERROR_DS_DUP_LINK_ID: int
ERROR_DS_NAME_ERROR_RESOLVING: int
ERROR_DS_NAME_ERROR_NOT_FOUND: int
ERROR_DS_NAME_ERROR_NOT_UNIQUE: int
ERROR_DS_NAME_ERROR_NO_MAPPING: int
ERROR_DS_NAME_ERROR_DOMAIN_ONLY: int
ERROR_DS_NAME_ERROR_NO_SYNTACTICAL_MAPPING: int
ERROR_DS_CONSTRUCTED_ATT_MOD: int
ERROR_DS_WRONG_OM_OBJ_CLASS: int
ERROR_DS_DRA_REPL_PENDING: int
ERROR_DS_DS_REQUIRED: int
ERROR_DS_INVALID_LDAP_DISPLAY_NAME: int
ERROR_DS_NON_BASE_SEARCH: int
ERROR_DS_CANT_RETRIEVE_ATTS: int
ERROR_DS_BACKLINK_WITHOUT_LINK: int
ERROR_DS_EPOCH_MISMATCH: int
ERROR_DS_SRC_NAME_MISMATCH: int
ERROR_DS_SRC_AND_DST_NC_IDENTICAL: int
ERROR_DS_DST_NC_MISMATCH: int
ERROR_DS_NOT_AUTHORITIVE_FOR_DST_NC: int
ERROR_DS_SRC_GUID_MISMATCH: int
ERROR_DS_CANT_MOVE_DELETED_OBJECT: int
ERROR_DS_PDC_OPERATION_IN_PROGRESS: int
ERROR_DS_CROSS_DOMAIN_CLEANUP_REQD: int
ERROR_DS_ILLEGAL_XDOM_MOVE_OPERATION: int
ERROR_DS_CANT_WITH_ACCT_GROUP_MEMBERSHPS: int
ERROR_DS_NC_MUST_HAVE_NC_PARENT: int
ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE: int
ERROR_DS_DST_DOMAIN_NOT_NATIVE: int
ERROR_DS_MISSING_INFRASTRUCTURE_CONTAINER: int
ERROR_DS_CANT_MOVE_ACCOUNT_GROUP: int
ERROR_DS_CANT_MOVE_RESOURCE_GROUP: int
ERROR_DS_INVALID_SEARCH_FLAG: int
ERROR_DS_NO_TREE_DELETE_ABOVE_NC: int
ERROR_DS_COULDNT_LOCK_TREE_FOR_DELETE: int
ERROR_DS_COULDNT_IDENTIFY_OBJECTS_FOR_TREE_DELETE: int
ERROR_DS_SAM_INIT_FAILURE: int
ERROR_DS_SENSITIVE_GROUP_VIOLATION: int
ERROR_DS_CANT_MOD_PRIMARYGROUPID: int
ERROR_DS_ILLEGAL_BASE_SCHEMA_MOD: int
ERROR_DS_NONSAFE_SCHEMA_CHANGE: int
ERROR_DS_SCHEMA_UPDATE_DISALLOWED: int
ERROR_DS_CANT_CREATE_UNDER_SCHEMA: int
ERROR_DS_INSTALL_NO_SRC_SCH_VERSION: int
ERROR_DS_INSTALL_NO_SCH_VERSION_IN_INIFILE: int
ERROR_DS_INVALID_GROUP_TYPE: int
ERROR_DS_NO_NEST_GLOBALGROUP_IN_MIXEDDOMAIN: int
ERROR_DS_NO_NEST_LOCALGROUP_IN_MIXEDDOMAIN: int
ERROR_DS_GLOBAL_CANT_HAVE_LOCAL_MEMBER: int
ERROR_DS_GLOBAL_CANT_HAVE_UNIVERSAL_MEMBER: int
ERROR_DS_UNIVERSAL_CANT_HAVE_LOCAL_MEMBER: int
ERROR_DS_GLOBAL_CANT_HAVE_CROSSDOMAIN_MEMBER: int
ERROR_DS_LOCAL_CANT_HAVE_CROSSDOMAIN_LOCAL_MEMBER: int
ERROR_DS_HAVE_PRIMARY_MEMBERS: int
ERROR_DS_STRING_SD_CONVERSION_FAILED: int
ERROR_DS_NAMING_MASTER_GC: int
ERROR_DS_DNS_LOOKUP_FAILURE: int
ERROR_DS_COULDNT_UPDATE_SPNS: int
ERROR_DS_CANT_RETRIEVE_SD: int
ERROR_DS_KEY_NOT_UNIQUE: int
ERROR_DS_WRONG_LINKED_ATT_SYNTAX: int
ERROR_DS_SAM_NEED_BOOTKEY_PASSWORD: int
ERROR_DS_SAM_NEED_BOOTKEY_FLOPPY: int
ERROR_DS_CANT_START: int
ERROR_DS_INIT_FAILURE: int
ERROR_DS_NO_PKT_PRIVACY_ON_CONNECTION: int
ERROR_DS_SOURCE_DOMAIN_IN_FOREST: int
ERROR_DS_DESTINATION_DOMAIN_NOT_IN_FOREST: int
ERROR_DS_DESTINATION_AUDITING_NOT_ENABLED: int
ERROR_DS_CANT_FIND_DC_FOR_SRC_DOMAIN: int
ERROR_DS_SRC_OBJ_NOT_GROUP_OR_USER: int
ERROR_DS_SRC_SID_EXISTS_IN_FOREST: int
ERROR_DS_SRC_AND_DST_OBJECT_CLASS_MISMATCH: int
ERROR_SAM_INIT_FAILURE: int
ERROR_DS_DRA_SCHEMA_INFO_SHIP: int
ERROR_DS_DRA_SCHEMA_CONFLICT: int
ERROR_DS_DRA_EARLIER_SCHEMA_CONFLICT: int
ERROR_DS_DRA_OBJ_NC_MISMATCH: int
ERROR_DS_NC_STILL_HAS_DSAS: int
ERROR_DS_GC_REQUIRED: int
ERROR_DS_LOCAL_MEMBER_OF_LOCAL_ONLY: int
ERROR_DS_NO_FPO_IN_UNIVERSAL_GROUPS: int
ERROR_DS_CANT_ADD_TO_GC: int
ERROR_DS_NO_CHECKPOINT_WITH_PDC: int
ERROR_DS_SOURCE_AUDITING_NOT_ENABLED: int
ERROR_DS_CANT_CREATE_IN_NONDOMAIN_NC: int
ERROR_DS_INVALID_NAME_FOR_SPN: int
ERROR_DS_FILTER_USES_CONTRUCTED_ATTRS: int
ERROR_DS_UNICODEPWD_NOT_IN_QUOTES: int
ERROR_DS_MACHINE_ACCOUNT_QUOTA_EXCEEDED: int
ERROR_DS_MUST_BE_RUN_ON_DST_DC: int
ERROR_DS_SRC_DC_MUST_BE_SP4_OR_GREATER: int
ERROR_DS_CANT_TREE_DELETE_CRITICAL_OBJ: int
ERROR_DS_INIT_FAILURE_CONSOLE: int
ERROR_DS_SAM_INIT_FAILURE_CONSOLE: int
ERROR_DS_FOREST_VERSION_TOO_HIGH: int
ERROR_DS_DOMAIN_VERSION_TOO_HIGH: int
ERROR_DS_FOREST_VERSION_TOO_LOW: int
ERROR_DS_DOMAIN_VERSION_TOO_LOW: int
ERROR_DS_INCOMPATIBLE_VERSION: int
ERROR_DS_LOW_DSA_VERSION: int
ERROR_DS_NO_BEHAVIOR_VERSION_IN_MIXEDDOMAIN: int
ERROR_DS_NOT_SUPPORTED_SORT_ORDER: int
ERROR_DS_NAME_NOT_UNIQUE: int
ERROR_DS_MACHINE_ACCOUNT_CREATED_PRENT4: int
ERROR_DS_OUT_OF_VERSION_STORE: int
ERROR_DS_INCOMPATIBLE_CONTROLS_USED: int
ERROR_DS_NO_REF_DOMAIN: int
ERROR_DS_RESERVED_LINK_ID: int
ERROR_DS_LINK_ID_NOT_AVAILABLE: int
ERROR_DS_AG_CANT_HAVE_UNIVERSAL_MEMBER: int
ERROR_DS_MODIFYDN_DISALLOWED_BY_INSTANCE_TYPE: int
ERROR_DS_NO_OBJECT_MOVE_IN_SCHEMA_NC: int
ERROR_DS_MODIFYDN_DISALLOWED_BY_FLAG: int
ERROR_DS_MODIFYDN_WRONG_GRANDPARENT: int
ERROR_DS_NAME_ERROR_TRUST_REFERRAL: int
ERROR_NOT_SUPPORTED_ON_STANDARD_SERVER: int
ERROR_DS_CANT_ACCESS_REMOTE_PART_OF_AD: int
ERROR_DS_CR_IMPOSSIBLE_TO_VALIDATE_V2: int
ERROR_DS_THREAD_LIMIT_EXCEEDED: int
ERROR_DS_NOT_CLOSEST: int
ERROR_DS_CANT_DERIVE_SPN_WITHOUT_SERVER_REF: int
ERROR_DS_SINGLE_USER_MODE_FAILED: int
ERROR_DS_NTDSCRIPT_SYNTAX_ERROR: int
ERROR_DS_NTDSCRIPT_PROCESS_ERROR: int
ERROR_DS_DIFFERENT_REPL_EPOCHS: int
ERROR_DS_DRS_EXTENSIONS_CHANGED: int
ERROR_DS_REPLICA_SET_CHANGE_NOT_ALLOWED_ON_DISABLED_CR: int
ERROR_DS_NO_MSDS_INTID: int
ERROR_DS_DUP_MSDS_INTID: int
ERROR_DS_EXISTS_IN_RDNATTID: int
ERROR_DS_AUTHORIZATION_FAILED: int
ERROR_DS_INVALID_SCRIPT: int
ERROR_DS_REMOTE_CROSSREF_OP_FAILED: int
ERROR_DS_CROSS_REF_BUSY: int
ERROR_DS_CANT_DERIVE_SPN_FOR_DELETED_DOMAIN: int
ERROR_DS_CANT_DEMOTE_WITH_WRITEABLE_NC: int
ERROR_DS_DUPLICATE_ID_FOUND: int
ERROR_DS_INSUFFICIENT_ATTR_TO_CREATE_OBJECT: int
ERROR_DS_GROUP_CONVERSION_ERROR: int
ERROR_DS_CANT_MOVE_APP_BASIC_GROUP: int
ERROR_DS_CANT_MOVE_APP_QUERY_GROUP: int
ERROR_DS_ROLE_NOT_VERIFIED: int
ERROR_DS_WKO_CONTAINER_CANNOT_BE_SPECIAL: int
ERROR_DS_DOMAIN_RENAME_IN_PROGRESS: int
ERROR_DS_EXISTING_AD_CHILD_NC: int
ERROR_DS_REPL_LIFETIME_EXCEEDED: int
ERROR_DS_DISALLOWED_IN_SYSTEM_CONTAINER: int
ERROR_DS_LDAP_SEND_QUEUE_FULL: int
ERROR_DS_DRA_OUT_SCHEDULE_WINDOW: int
ERROR_DS_POLICY_NOT_KNOWN: int
ERROR_NO_SITE_SETTINGS_OBJECT: int
ERROR_NO_SECRETS: int
ERROR_NO_WRITABLE_DC_FOUND: int
ERROR_DS_NO_SERVER_OBJECT: int
ERROR_DS_NO_NTDSA_OBJECT: int
ERROR_DS_NON_ASQ_SEARCH: int
ERROR_DS_AUDIT_FAILURE: int
ERROR_DS_INVALID_SEARCH_FLAG_SUBTREE: int
ERROR_DS_INVALID_SEARCH_FLAG_TUPLE: int
ERROR_DS_HIERARCHY_TABLE_TOO_DEEP: int
SEVERITY_SUCCESS: int
SEVERITY_ERROR: int

def HRESULT_FROM_WIN32(scode): ...
def SUCCEEDED(Status): ...
def FAILED(Status): ...
def HRESULT_CODE(hr: int) -> int: ...
def SCODE_CODE(sc): ...
def HRESULT_FACILITY(hr): ...
def SCODE_FACILITY(sc): ...
def HRESULT_SEVERITY(hr): ...
def SCODE_SEVERITY(sc): ...

FACILITY_NT_BIT: int

def HRESULT_FROM_NT(x): ...
def GetScode(hr): ...
def ResultFromScode(sc): ...

NOERROR: int
E_UNEXPECTED: int
E_NOTIMPL: int
E_OUTOFMEMORY: int
E_INVALIDARG: int
E_NOINTERFACE: int
E_POINTER: int
E_HANDLE: int
E_ABORT: int
E_FAIL: int
E_ACCESSDENIED: int
win16_E_NOTIMPL: int
win16_E_OUTOFMEMORY: int
win16_E_INVALIDARG: int
win16_E_NOINTERFACE: int
win16_E_POINTER: int
win16_E_HANDLE: int
win16_E_ABORT: int
win16_E_FAIL: int
win16_E_ACCESSDENIED: int
E_PENDING: int
CO_E_INIT_TLS: int
CO_E_INIT_SHARED_ALLOCATOR: int
CO_E_INIT_MEMORY_ALLOCATOR: int
CO_E_INIT_CLASS_CACHE: int
CO_E_INIT_RPC_CHANNEL: int
CO_E_INIT_TLS_SET_CHANNEL_CONTROL: int
CO_E_INIT_TLS_CHANNEL_CONTROL: int
CO_E_INIT_UNACCEPTED_USER_ALLOCATOR: int
CO_E_INIT_SCM_MUTEX_EXISTS: int
CO_E_INIT_SCM_FILE_MAPPING_EXISTS: int
CO_E_INIT_SCM_MAP_VIEW_OF_FILE: int
CO_E_INIT_SCM_EXEC_FAILURE: int
CO_E_INIT_ONLY_SINGLE_THREADED: int
CO_E_CANT_REMOTE: int
CO_E_BAD_SERVER_NAME: int
CO_E_WRONG_SERVER_IDENTITY: int
CO_E_OLE1DDE_DISABLED: int
CO_E_RUNAS_SYNTAX: int
CO_E_CREATEPROCESS_FAILURE: int
CO_E_RUNAS_CREATEPROCESS_FAILURE: int
CO_E_RUNAS_LOGON_FAILURE: int
CO_E_LAUNCH_PERMSSION_DENIED: int
CO_E_START_SERVICE_FAILURE: int
CO_E_REMOTE_COMMUNICATION_FAILURE: int
CO_E_SERVER_START_TIMEOUT: int
CO_E_CLSREG_INCONSISTENT: int
CO_E_IIDREG_INCONSISTENT: int
CO_E_NOT_SUPPORTED: int
CO_E_RELOAD_DLL: int
CO_E_MSI_ERROR: int
OLE_E_FIRST: int
OLE_E_LAST: int
OLE_S_FIRST: int
OLE_S_LAST: int
OLE_E_OLEVERB: int
OLE_E_ADVF: int
OLE_E_ENUM_NOMORE: int
OLE_E_ADVISENOTSUPPORTED: int
OLE_E_NOCONNECTION: int
OLE_E_NOTRUNNING: int
OLE_E_NOCACHE: int
OLE_E_BLANK: int
OLE_E_CLASSDIFF: int
OLE_E_CANT_GETMONIKER: int
OLE_E_CANT_BINDTOSOURCE: int
OLE_E_STATIC: int
OLE_E_PROMPTSAVECANCELLED: int
OLE_E_INVALIDRECT: int
OLE_E_WRONGCOMPOBJ: int
OLE_E_INVALIDHWND: int
OLE_E_NOT_INPLACEACTIVE: int
OLE_E_CANTCONVERT: int
OLE_E_NOSTORAGE: int
DV_E_FORMATETC: int
DV_E_DVTARGETDEVICE: int
DV_E_STGMEDIUM: int
DV_E_STATDATA: int
DV_E_LINDEX: int
DV_E_TYMED: int
DV_E_CLIPFORMAT: int
DV_E_DVASPECT: int
DV_E_DVTARGETDEVICE_SIZE: int
DV_E_NOIVIEWOBJECT: int
DRAGDROP_E_FIRST: int
DRAGDROP_E_LAST: int
DRAGDROP_S_FIRST: int
DRAGDROP_S_LAST: int
DRAGDROP_E_NOTREGISTERED: int
DRAGDROP_E_ALREADYREGISTERED: int
DRAGDROP_E_INVALIDHWND: int
CLASSFACTORY_E_FIRST: int
CLASSFACTORY_E_LAST: int
CLASSFACTORY_S_FIRST: int
CLASSFACTORY_S_LAST: int
CLASS_E_NOAGGREGATION: int
CLASS_E_CLASSNOTAVAILABLE: int
CLASS_E_NOTLICENSED: int
MARSHAL_E_FIRST: int
MARSHAL_E_LAST: int
MARSHAL_S_FIRST: int
MARSHAL_S_LAST: int
DATA_E_FIRST: int
DATA_E_LAST: int
DATA_S_FIRST: int
DATA_S_LAST: int
VIEW_E_FIRST: int
VIEW_E_LAST: int
VIEW_S_FIRST: int
VIEW_S_LAST: int
VIEW_E_DRAW: int
REGDB_E_FIRST: int
REGDB_E_LAST: int
REGDB_S_FIRST: int
REGDB_S_LAST: int
REGDB_E_READREGDB: int
REGDB_E_WRITEREGDB: int
REGDB_E_KEYMISSING: int
REGDB_E_INVALIDVALUE: int
REGDB_E_CLASSNOTREG: int
REGDB_E_IIDNOTREG: int
CAT_E_FIRST: int
CAT_E_LAST: int
CAT_E_CATIDNOEXIST: int
CAT_E_NODESCRIPTION: int
CS_E_FIRST: int
CS_E_LAST: int
CS_E_PACKAGE_NOTFOUND: int
CS_E_NOT_DELETABLE: int
CS_E_CLASS_NOTFOUND: int
CS_E_INVALID_VERSION: int
CS_E_NO_CLASSSTORE: int
CACHE_E_FIRST: int
CACHE_E_LAST: int
CACHE_S_FIRST: int
CACHE_S_LAST: int
CACHE_E_NOCACHE_UPDATED: int
OLEOBJ_E_FIRST: int
OLEOBJ_E_LAST: int
OLEOBJ_S_FIRST: int
OLEOBJ_S_LAST: int
OLEOBJ_E_NOVERBS: int
OLEOBJ_E_INVALIDVERB: int
CLIENTSITE_E_FIRST: int
CLIENTSITE_E_LAST: int
CLIENTSITE_S_FIRST: int
CLIENTSITE_S_LAST: int
INPLACE_E_NOTUNDOABLE: int
INPLACE_E_NOTOOLSPACE: int
INPLACE_E_FIRST: int
INPLACE_E_LAST: int
INPLACE_S_FIRST: int
INPLACE_S_LAST: int
ENUM_E_FIRST: int
ENUM_E_LAST: int
ENUM_S_FIRST: int
ENUM_S_LAST: int
CONVERT10_E_FIRST: int
CONVERT10_E_LAST: int
CONVERT10_S_FIRST: int
CONVERT10_S_LAST: int
CONVERT10_E_OLESTREAM_GET: int
CONVERT10_E_OLESTREAM_PUT: int
CONVERT10_E_OLESTREAM_FMT: int
CONVERT10_E_OLESTREAM_BITMAP_TO_DIB: int
CONVERT10_E_STG_FMT: int
CONVERT10_E_STG_NO_STD_STREAM: int
CONVERT10_E_STG_DIB_TO_BITMAP: int
CLIPBRD_E_FIRST: int
CLIPBRD_E_LAST: int
CLIPBRD_S_FIRST: int
CLIPBRD_S_LAST: int
CLIPBRD_E_CANT_OPEN: int
CLIPBRD_E_CANT_EMPTY: int
CLIPBRD_E_CANT_SET: int
CLIPBRD_E_BAD_DATA: int
CLIPBRD_E_CANT_CLOSE: int
MK_E_FIRST: int
MK_E_LAST: int
MK_S_FIRST: int
MK_S_LAST: int
MK_E_CONNECTMANUALLY: int
MK_E_EXCEEDEDDEADLINE: int
MK_E_NEEDGENERIC: int
MK_E_UNAVAILABLE: int
MK_E_SYNTAX: int
MK_E_NOOBJECT: int
MK_E_INVALIDEXTENSION: int
MK_E_INTERMEDIATEINTERFACENOTSUPPORTED: int
MK_E_NOTBINDABLE: int
MK_E_NOTBOUND: int
MK_E_CANTOPENFILE: int
MK_E_MUSTBOTHERUSER: int
MK_E_NOINVERSE: int
MK_E_NOSTORAGE: int
MK_E_NOPREFIX: int
MK_E_ENUMERATION_FAILED: int
CO_E_FIRST: int
CO_E_LAST: int
CO_S_FIRST: int
CO_S_LAST: int
CO_E_NOTINITIALIZED: int
CO_E_ALREADYINITIALIZED: int
CO_E_CANTDETERMINECLASS: int
CO_E_CLASSSTRING: int
CO_E_IIDSTRING: int
CO_E_APPNOTFOUND: int
CO_E_APPSINGLEUSE: int
CO_E_ERRORINAPP: int
CO_E_DLLNOTFOUND: int
CO_E_ERRORINDLL: int
CO_E_WRONGOSFORAPP: int
CO_E_OBJNOTREG: int
CO_E_OBJISREG: int
CO_E_OBJNOTCONNECTED: int
CO_E_APPDIDNTREG: int
CO_E_RELEASED: int
CO_E_FAILEDTOIMPERSONATE: int
CO_E_FAILEDTOGETSECCTX: int
CO_E_FAILEDTOOPENTHREADTOKEN: int
CO_E_FAILEDTOGETTOKENINFO: int
CO_E_TRUSTEEDOESNTMATCHCLIENT: int
CO_E_FAILEDTOQUERYCLIENTBLANKET: int
CO_E_FAILEDTOSETDACL: int
CO_E_ACCESSCHECKFAILED: int
CO_E_NETACCESSAPIFAILED: int
CO_E_WRONGTRUSTEENAMESYNTAX: int
CO_E_INVALIDSID: int
CO_E_CONVERSIONFAILED: int
CO_E_NOMATCHINGSIDFOUND: int
CO_E_LOOKUPACCSIDFAILED: int
CO_E_NOMATCHINGNAMEFOUND: int
CO_E_LOOKUPACCNAMEFAILED: int
CO_E_SETSERLHNDLFAILED: int
CO_E_FAILEDTOGETWINDIR: int
CO_E_PATHTOOLONG: int
CO_E_FAILEDTOGENUUID: int
CO_E_FAILEDTOCREATEFILE: int
CO_E_FAILEDTOCLOSEHANDLE: int
CO_E_EXCEEDSYSACLLIMIT: int
CO_E_ACESINWRONGORDER: int
CO_E_INCOMPATIBLESTREAMVERSION: int
CO_E_FAILEDTOOPENPROCESSTOKEN: int
CO_E_DECODEFAILED: int
CO_E_ACNOTINITIALIZED: int
OLE_S_USEREG: int
OLE_S_STATIC: int
OLE_S_MAC_CLIPFORMAT: int
DRAGDROP_S_DROP: int
DRAGDROP_S_CANCEL: int
DRAGDROP_S_USEDEFAULTCURSORS: int
DATA_S_SAMEFORMATETC: int
VIEW_S_ALREADY_FROZEN: int
CACHE_S_FORMATETC_NOTSUPPORTED: int
CACHE_S_SAMECACHE: int
CACHE_S_SOMECACHES_NOTUPDATED: int
OLEOBJ_S_INVALIDVERB: int
OLEOBJ_S_CANNOT_DOVERB_NOW: int
OLEOBJ_S_INVALIDHWND: int
INPLACE_S_TRUNCATED: int
CONVERT10_S_NO_PRESENTATION: int
MK_S_REDUCED_TO_SELF: int
MK_S_ME: int
MK_S_HIM: int
MK_S_US: int
MK_S_MONIKERALREADYREGISTERED: int
CO_E_CLASS_CREATE_FAILED: int
CO_E_SCM_ERROR: int
CO_E_SCM_RPC_FAILURE: int
CO_E_BAD_PATH: int
CO_E_SERVER_EXEC_FAILURE: int
CO_E_OBJSRV_RPC_FAILURE: int
MK_E_NO_NORMALIZED: int
CO_E_SERVER_STOPPING: int
MEM_E_INVALID_ROOT: int
MEM_E_INVALID_LINK: int
MEM_E_INVALID_SIZE: int
CO_S_NOTALLINTERFACES: int
DISP_E_UNKNOWNINTERFACE: int
DISP_E_MEMBERNOTFOUND: int
DISP_E_PARAMNOTFOUND: int
DISP_E_TYPEMISMATCH: int
DISP_E_UNKNOWNNAME: int
DISP_E_NONAMEDARGS: int
DISP_E_BADVARTYPE: int
DISP_E_EXCEPTION: int
DISP_E_OVERFLOW: int
DISP_E_BADINDEX: int
DISP_E_UNKNOWNLCID: int
DISP_E_ARRAYISLOCKED: int
DISP_E_BADPARAMCOUNT: int
DISP_E_PARAMNOTOPTIONAL: int
DISP_E_BADCALLEE: int
DISP_E_NOTACOLLECTION: int
DISP_E_DIVBYZERO: int
TYPE_E_BUFFERTOOSMALL: int
TYPE_E_FIELDNOTFOUND: int
TYPE_E_INVDATAREAD: int
TYPE_E_UNSUPFORMAT: int
TYPE_E_REGISTRYACCESS: int
TYPE_E_LIBNOTREGISTERED: int
TYPE_E_UNDEFINEDTYPE: int
TYPE_E_QUALIFIEDNAMEDISALLOWED: int
TYPE_E_INVALIDSTATE: int
TYPE_E_WRONGTYPEKIND: int
TYPE_E_ELEMENTNOTFOUND: int
TYPE_E_AMBIGUOUSNAME: int
TYPE_E_NAMECONFLICT: int
TYPE_E_UNKNOWNLCID: int
TYPE_E_DLLFUNCTIONNOTFOUND: int
TYPE_E_BADMODULEKIND: int
TYPE_E_SIZETOOBIG: int
TYPE_E_DUPLICATEID: int
TYPE_E_INVALIDID: int
TYPE_E_TYPEMISMATCH: int
TYPE_E_OUTOFBOUNDS: int
TYPE_E_IOERROR: int
TYPE_E_CANTCREATETMPFILE: int
TYPE_E_CANTLOADLIBRARY: int
TYPE_E_INCONSISTENTPROPFUNCS: int
TYPE_E_CIRCULARTYPE: int
STG_E_INVALIDFUNCTION: int
STG_E_FILENOTFOUND: int
STG_E_PATHNOTFOUND: int
STG_E_TOOMANYOPENFILES: int
STG_E_ACCESSDENIED: int
STG_E_INVALIDHANDLE: int
STG_E_INSUFFICIENTMEMORY: int
STG_E_INVALIDPOINTER: int
STG_E_NOMOREFILES: int
STG_E_DISKISWRITEPROTECTED: int
STG_E_SEEKERROR: int
STG_E_WRITEFAULT: int
STG_E_READFAULT: int
STG_E_SHAREVIOLATION: int
STG_E_LOCKVIOLATION: int
STG_E_FILEALREADYEXISTS: int
STG_E_INVALIDPARAMETER: int
STG_E_MEDIUMFULL: int
STG_E_PROPSETMISMATCHED: int
STG_E_ABNORMALAPIEXIT: int
STG_E_INVALIDHEADER: int
STG_E_INVALIDNAME: int
STG_E_UNKNOWN: int
STG_E_UNIMPLEMENTEDFUNCTION: int
STG_E_INVALIDFLAG: int
STG_E_INUSE: int
STG_E_NOTCURRENT: int
STG_E_REVERTED: int
STG_E_CANTSAVE: int
STG_E_OLDFORMAT: int
STG_E_OLDDLL: int
STG_E_SHAREREQUIRED: int
STG_E_NOTFILEBASEDSTORAGE: int
STG_E_EXTANTMARSHALLINGS: int
STG_E_DOCFILECORRUPT: int
STG_E_BADBASEADDRESS: int
STG_E_INCOMPLETE: int
STG_E_TERMINATED: int
STG_S_CONVERTED: int
STG_S_BLOCK: int
STG_S_RETRYNOW: int
STG_S_MONITORING: int
STG_S_MULTIPLEOPENS: int
STG_S_CONSOLIDATIONFAILED: int
STG_S_CANNOTCONSOLIDATE: int
RPC_E_CALL_REJECTED: int
RPC_E_CALL_CANCELED: int
RPC_E_CANTPOST_INSENDCALL: int
RPC_E_CANTCALLOUT_INASYNCCALL: int
RPC_E_CANTCALLOUT_INEXTERNALCALL: int
RPC_E_CONNECTION_TERMINATED: int
RPC_E_SERVER_DIED: int
RPC_E_CLIENT_DIED: int
RPC_E_INVALID_DATAPACKET: int
RPC_E_CANTTRANSMIT_CALL: int
RPC_E_CLIENT_CANTMARSHAL_DATA: int
RPC_E_CLIENT_CANTUNMARSHAL_DATA: int
RPC_E_SERVER_CANTMARSHAL_DATA: int
RPC_E_SERVER_CANTUNMARSHAL_DATA: int
RPC_E_INVALID_DATA: int
RPC_E_INVALID_PARAMETER: int
RPC_E_CANTCALLOUT_AGAIN: int
RPC_E_SERVER_DIED_DNE: int
RPC_E_SYS_CALL_FAILED: int
RPC_E_OUT_OF_RESOURCES: int
RPC_E_ATTEMPTED_MULTITHREAD: int
RPC_E_NOT_REGISTERED: int
RPC_E_FAULT: int
RPC_E_SERVERFAULT: int
RPC_E_CHANGED_MODE: int
RPC_E_INVALIDMETHOD: int
RPC_E_DISCONNECTED: int
RPC_E_RETRY: int
RPC_E_SERVERCALL_RETRYLATER: int
RPC_E_SERVERCALL_REJECTED: int
RPC_E_INVALID_CALLDATA: int
RPC_E_CANTCALLOUT_ININPUTSYNCCALL: int
RPC_E_WRONG_THREAD: int
RPC_E_THREAD_NOT_INIT: int
RPC_E_VERSION_MISMATCH: int
RPC_E_INVALID_HEADER: int
RPC_E_INVALID_EXTENSION: int
RPC_E_INVALID_IPID: int
RPC_E_INVALID_OBJECT: int
RPC_S_CALLPENDING: int
RPC_S_WAITONTIMER: int
RPC_E_CALL_COMPLETE: int
RPC_E_UNSECURE_CALL: int
RPC_E_TOO_LATE: int
RPC_E_NO_GOOD_SECURITY_PACKAGES: int
RPC_E_ACCESS_DENIED: int
RPC_E_REMOTE_DISABLED: int
RPC_E_INVALID_OBJREF: int
RPC_E_NO_CONTEXT: int
RPC_E_TIMEOUT: int
RPC_E_NO_SYNC: int
RPC_E_UNEXPECTED: int
NTE_BAD_UID: int
NTE_BAD_HASH: int
NTE_BAD_KEY: int
NTE_BAD_LEN: int
NTE_BAD_DATA: int
NTE_BAD_SIGNATURE: int
NTE_BAD_VER: int
NTE_BAD_ALGID: int
NTE_BAD_FLAGS: int
NTE_BAD_TYPE: int
NTE_BAD_KEY_STATE: int
NTE_BAD_HASH_STATE: int
NTE_NO_KEY: int
NTE_NO_MEMORY: int
NTE_EXISTS: int
NTE_PERM: int
NTE_NOT_FOUND: int
NTE_DOUBLE_ENCRYPT: int
NTE_BAD_PROVIDER: int
NTE_BAD_PROV_TYPE: int
NTE_BAD_PUBLIC_KEY: int
NTE_BAD_KEYSET: int
NTE_PROV_TYPE_NOT_DEF: int
NTE_PROV_TYPE_ENTRY_BAD: int
NTE_KEYSET_NOT_DEF: int
NTE_KEYSET_ENTRY_BAD: int
NTE_PROV_TYPE_NO_MATCH: int
NTE_SIGNATURE_FILE_BAD: int
NTE_PROVIDER_DLL_FAIL: int
NTE_PROV_DLL_NOT_FOUND: int
NTE_BAD_KEYSET_PARAM: int
NTE_FAIL: int
NTE_SYS_ERR: int
CRYPT_E_MSG_ERROR: int
CRYPT_E_UNKNOWN_ALGO: int
CRYPT_E_OID_FORMAT: int
CRYPT_E_INVALID_MSG_TYPE: int
CRYPT_E_UNEXPECTED_ENCODING: int
CRYPT_E_AUTH_ATTR_MISSING: int
CRYPT_E_HASH_VALUE: int
CRYPT_E_INVALID_INDEX: int
CRYPT_E_ALREADY_DECRYPTED: int
CRYPT_E_NOT_DECRYPTED: int
CRYPT_E_RECIPIENT_NOT_FOUND: int
CRYPT_E_CONTROL_TYPE: int
CRYPT_E_ISSUER_SERIALNUMBER: int
CRYPT_E_SIGNER_NOT_FOUND: int
CRYPT_E_ATTRIBUTES_MISSING: int
CRYPT_E_STREAM_MSG_NOT_READY: int
CRYPT_E_STREAM_INSUFFICIENT_DATA: int
CRYPT_E_BAD_LEN: int
CRYPT_E_BAD_ENCODE: int
CRYPT_E_FILE_ERROR: int
CRYPT_E_NOT_FOUND: int
CRYPT_E_EXISTS: int
CRYPT_E_NO_PROVIDER: int
CRYPT_E_SELF_SIGNED: int
CRYPT_E_DELETED_PREV: int
CRYPT_E_NO_MATCH: int
CRYPT_E_UNEXPECTED_MSG_TYPE: int
CRYPT_E_NO_KEY_PROPERTY: int
CRYPT_E_NO_DECRYPT_CERT: int
CRYPT_E_BAD_MSG: int
CRYPT_E_NO_SIGNER: int
CRYPT_E_PENDING_CLOSE: int
CRYPT_E_REVOKED: int
CRYPT_E_NO_REVOCATION_DLL: int
CRYPT_E_NO_REVOCATION_CHECK: int
CRYPT_E_REVOCATION_OFFLINE: int
CRYPT_E_NOT_IN_REVOCATION_DATABASE: int
CRYPT_E_INVALID_NUMERIC_STRING: int
CRYPT_E_INVALID_PRINTABLE_STRING: int
CRYPT_E_INVALID_IA5_STRING: int
CRYPT_E_INVALID_X500_STRING: int
CRYPT_E_NOT_CHAR_STRING: int
CRYPT_E_FILERESIZED: int
CRYPT_E_SECURITY_SETTINGS: int
CRYPT_E_NO_VERIFY_USAGE_DLL: int
CRYPT_E_NO_VERIFY_USAGE_CHECK: int
CRYPT_E_VERIFY_USAGE_OFFLINE: int
CRYPT_E_NOT_IN_CTL: int
CRYPT_E_NO_TRUSTED_SIGNER: int
CRYPT_E_OSS_ERROR: int
CERTSRV_E_BAD_REQUESTSUBJECT: int
CERTSRV_E_NO_REQUEST: int
CERTSRV_E_BAD_REQUESTSTATUS: int
CERTSRV_E_PROPERTY_EMPTY: int
CERTDB_E_JET_ERROR: int
TRUST_E_SYSTEM_ERROR: int
TRUST_E_NO_SIGNER_CERT: int
TRUST_E_COUNTER_SIGNER: int
TRUST_E_CERT_SIGNATURE: int
TRUST_E_TIME_STAMP: int
TRUST_E_BAD_DIGEST: int
TRUST_E_BASIC_CONSTRAINTS: int
TRUST_E_FINANCIAL_CRITERIA: int
NTE_OP_OK: int
DIGSIG_E_ENCODE: int
DIGSIG_E_DECODE: int
DIGSIG_E_EXTENSIBILITY: int
DIGSIG_E_CRYPTO: int
PERSIST_E_SIZEDEFINITE: int
PERSIST_E_SIZEINDEFINITE: int
PERSIST_E_NOTSELFSIZING: int
TRUST_E_NOSIGNATURE: int
CERT_E_EXPIRED: int
CERT_E_VALIDITYPERIODNESTING: int
CERT_E_ROLE: int
CERT_E_PATHLENCONST: int
CERT_E_CRITICAL: int
CERT_E_PURPOSE: int
CERT_E_ISSUERCHAINING: int
CERT_E_MALFORMED: int
CERT_E_UNTRUSTEDROOT: int
CERT_E_CHAINING: int
TRUST_E_FAIL: int
CERT_E_REVOKED: int
CERT_E_UNTRUSTEDTESTROOT: int
CERT_E_REVOCATION_FAILURE: int
CERT_E_CN_NO_MATCH: int
CERT_E_WRONG_USAGE: int
SPAPI_E_EXPECTED_SECTION_NAME: int
SPAPI_E_BAD_SECTION_NAME_LINE: int
SPAPI_E_SECTION_NAME_TOO_LONG: int
SPAPI_E_GENERAL_SYNTAX: int
SPAPI_E_WRONG_INF_STYLE: int
SPAPI_E_SECTION_NOT_FOUND: int
SPAPI_E_LINE_NOT_FOUND: int
SPAPI_E_NO_ASSOCIATED_CLASS: int
SPAPI_E_CLASS_MISMATCH: int
SPAPI_E_DUPLICATE_FOUND: int
SPAPI_E_NO_DRIVER_SELECTED: int
SPAPI_E_KEY_DOES_NOT_EXIST: int
SPAPI_E_INVALID_DEVINST_NAME: int
SPAPI_E_INVALID_CLASS: int
SPAPI_E_DEVINST_ALREADY_EXISTS: int
SPAPI_E_DEVINFO_NOT_REGISTERED: int
SPAPI_E_INVALID_REG_PROPERTY: int
SPAPI_E_NO_INF: int
SPAPI_E_NO_SUCH_DEVINST: int
SPAPI_E_CANT_LOAD_CLASS_ICON: int
SPAPI_E_INVALID_CLASS_INSTALLER: int
SPAPI_E_DI_DO_DEFAULT: int
SPAPI_E_DI_NOFILECOPY: int
SPAPI_E_INVALID_HWPROFILE: int
SPAPI_E_NO_DEVICE_SELECTED: int
SPAPI_E_DEVINFO_LIST_LOCKED: int
SPAPI_E_DEVINFO_DATA_LOCKED: int
SPAPI_E_DI_BAD_PATH: int
SPAPI_E_NO_CLASSINSTALL_PARAMS: int
SPAPI_E_FILEQUEUE_LOCKED: int
SPAPI_E_BAD_SERVICE_INSTALLSECT: int
SPAPI_E_NO_CLASS_DRIVER_LIST: int
SPAPI_E_NO_ASSOCIATED_SERVICE: int
SPAPI_E_NO_DEFAULT_DEVICE_INTERFACE: int
SPAPI_E_DEVICE_INTERFACE_ACTIVE: int
SPAPI_E_DEVICE_INTERFACE_REMOVED: int
SPAPI_E_BAD_INTERFACE_INSTALLSECT: int
SPAPI_E_NO_SUCH_INTERFACE_CLASS: int
SPAPI_E_INVALID_REFERENCE_STRING: int
SPAPI_E_INVALID_MACHINENAME: int
SPAPI_E_REMOTE_COMM_FAILURE: int
SPAPI_E_MACHINE_UNAVAILABLE: int
SPAPI_E_NO_CONFIGMGR_SERVICES: int
SPAPI_E_INVALID_PROPPAGE_PROVIDER: int
SPAPI_E_NO_SUCH_DEVICE_INTERFACE: int
SPAPI_E_DI_POSTPROCESSING_REQUIRED: int
SPAPI_E_INVALID_COINSTALLER: int
SPAPI_E_NO_COMPAT_DRIVERS: int
SPAPI_E_NO_DEVICE_ICON: int
SPAPI_E_INVALID_INF_LOGCONFIG: int
SPAPI_E_DI_DONT_INSTALL: int
SPAPI_E_INVALID_FILTER_DRIVER: int
SPAPI_E_ERROR_NOT_INSTALLED: int
CDERR_DIALOGFAILURE: int
CDERR_GENERALCODES: int
CDERR_STRUCTSIZE: int
CDERR_INITIALIZATION: int
CDERR_NOTEMPLATE: int
CDERR_NOHINSTANCE: int
CDERR_LOADSTRFAILURE: int
CDERR_FINDRESFAILURE: int
CDERR_LOADRESFAILURE: int
CDERR_LOCKRESFAILURE: int
CDERR_MEMALLOCFAILURE: int
CDERR_MEMLOCKFAILURE: int
CDERR_NOHOOK: int
CDERR_REGISTERMSGFAIL: int
PDERR_PRINTERCODES: int
PDERR_SETUPFAILURE: int
PDERR_PARSEFAILURE: int
PDERR_RETDEFFAILURE: int
PDERR_LOADDRVFAILURE: int
PDERR_GETDEVMODEFAIL: int
PDERR_INITFAILURE: int
PDERR_NODEVICES: int
PDERR_NODEFAULTPRN: int
PDERR_DNDMMISMATCH: int
PDERR_CREATEICFAILURE: int
PDERR_PRINTERNOTFOUND: int
PDERR_DEFAULTDIFFERENT: int
CFERR_CHOOSEFONTCODES: int
CFERR_NOFONTS: int
CFERR_MAXLESSTHANMIN: int
FNERR_FILENAMECODES: int
FNERR_SUBCLASSFAILURE: int
FNERR_INVALIDFILENAME: int
FNERR_BUFFERTOOSMALL: int
FRERR_FINDREPLACECODES: int
FRERR_BUFFERLENGTHZERO: int
CCERR_CHOOSECOLORCODES: int
